<?php

$seedprod_basic_lpage = '
{
    "show_header_template": true,
    "show_footer_template": true,
    "no_conflict_mode": false,
    "no_index": false,
    "seo_title": "",
    "seo_description": "",
    "favicon": "",
    "social_thumbnail": "",
    "enable_recaptcha": false,
    "template_id":"",
    "post_title":"",
    "post_name":"",
    "post_status":"",
    "show_powered_by_link":false,
    "facebook_app_id":"",
    "affiliate_url":"",
    "header_scripts":"",
    "body_scripts":"",
    "footer_scripts":"",
    "conversion_scripts":"",
    "disable_default_excluded_urls": false,
    "include_exclude_type": "0",
    "include_list": "",
    "exclude_list": "",
    "bypass_phrase": "",
    "bypass_expires": "2",
    "bypass_cookie": false,
    "access_by_ip":"",
    "access_by_role":[],
    "redirect_login_page":false,
    "redirect_mode":false,
    "redirect_url":"",
    "domain_mapping_status":false,
    "domain_mapping":"",
    "domain_mapping_force_https":false,
    "exclude_list_404":"",
    "email_integration_id":"",
    "document":{
        "sections":[],
        "settings":{
           "bgStyle": "s",
           "bgGradient":{ "type": "linear","position": "center", "angle": 0,"color1":"","color1location":0,"color2":"","color2location":100 },
           "bgColor":"#FFFFFF",
           "bgImage":"",
           "bgDimming":0,
           "bgCustomDimming":0,
          "bgCustomDimmingOverlay":"",
          "bgCustomXPositionUnit":"px",
          "bgCustomXPosition":"",
          "bgCustomYPositionUnit":"px",
          "bgCustomYPosition":"",
          "bgCustomAttachment":"",
          "bgCustomRepeat":"",
          "bgCustomSize":"",
          "bgCustomSizeWidthUnit":"%",
          "bgCustomSizeWidth":"100",
           "bgOverlayColor":"",
           "bgPosition":"cover",
           "buttonColor":"#000000",
           "headerColor":"#000000",
           "linkColor":"#FF0000",
           "linkDarkerColor":"#cc0000",
           "textColor":"#272727",
           "textFont":"\'Helvetica Neue\', Arial, sans-serif",
           "textFontVariant":"400",
           "headerFont":"\'Helvetica Neue\', Arial, sans-serif",
           "headerFontVariant":"400",
           "contentPosition":"1",
           "customCss":"",
           "headCss":"",
           "mobileCss":"",
           "mobileVisibilityCss":"",
           "desktopVisibilityCss":"",
           "placeholderCss":"",
           "useVideoBg":false,
           "useVideoBgUrl":"",
           "useSlideshowBg": false,
           "useSlideshowImgs": [""]

        }
     }
 }
 ';

$seedprod_current_content = '
 [
  {
     "id":"ks8a8s",
     "type":"section",
     "rows":[
        {
           "id":"vw3kvy",
           "type":"row",
           "colType":"1-col",
           "cols":[
              {
                 "id":"iw5h09",
                 "type":"col",
                 "blocks":[
                    {
                       "id":"jzzxne",
                       "elType":"block",
                       "type":"text",
                       "settings":{
                          "txt":"current_content",
                          "textColor":"",
                          "bgColor":"",
                          "beforeIcon":"",
                          "afterIcon":"",
                          "marginTop":"",
                          "marginBottom": "",
                          "marginLeft": "",
                          "marginRight": "",
                          "marginSync": false,
                          "customClass":"",
                          "paddingTop":"",
                          "paddingBottom":"",
                          "paddingLeft":"",
                          "paddingRight":"",
                          "paddingSync":true,
                          "borderRadius":"",
                          "border":"",
                          "borderStyle":"",
                          "borderSize":"",
                          "borderColor":"",
                          "shadow":"",
                          "textShadow":"",
                          "font":"",
                          "fontVariant":"",
                          "fontSize":"",
                          "fontSize_mobile":"",
                          "lineHeight":"",
                          "lineHeight_mobile":"",
                          "letterSpacing":"",
                          "letterSpacing_mobile":"",
                          "typographyBold":"",
                          "typographyItalic":"",
                          "typographyUnderline":"",
                          "align":"left",
                          "typographyLetterCase":"",
                          "hideOnDesktop": false,
                          "hideOnMobile": false
                       }
                    }
                 ],
                 "settings":{
                    "bgStyle":"s",
                    "bgGradient":{
                       "type":"linear",
                       "position":"center",
                       "angle":0,
                       "color1":"",
                       "color1location":0,
                       "color2":"",
                       "color2location":100
                    },
                    "colWidth":"",
                    "bgColor":"",
                    "bgImage":"",
                    "bgPosition":"",
                    "marginTop":"",
                    "marginBottom": "",
                    "marginLeft": "",
                    "marginRight": "",
                    "marginSync": false,
                    "customClass":"",
                    "shadow":"",
                    "paddingTop":"",
                    "paddingBottom":"",
                    "paddingLeft":"",
                    "paddingRight":"",
                    "paddingSync":true,
                    "borderRadiusTL":"",
                    "borderRadiusTR":"",
                    "borderRadiusBL":"",
                    "borderRadiusBR":"",
                    "borderRadiusSync":true,
                    "borderTop":"0",
                    "borderBottom":"0",
                    "borderLeft":"0",
                    "borderRight":"0",
                    "borderSync":true,
                    "borderStyle":"solid"
                 }
              }
           ],
           "settings":{
              "bgStyle":"s",
              "bgGradient":{
                 "type":"linear",
                 "position":"center",
                 "angle":0,
                 "color1":"",
                 "color1location":0,
                 "color2":"",
                 "color2location":100
              },
              "colGutter":0,
              "width":"",
              "bgColor":"",
              "bgImage":"",
              "bgPosition":"",
              "marginTop":"",
              "marginBottom": "",
              "marginLeft": "",
              "marginRight": "",
              "marginSync": false,
              "customClass":"",
              "shadow":"",
              "paddingTop":"",
              "paddingBottom":"",
              "paddingLeft":"",
              "paddingRight":"",
              "paddingSync":true,
              "borderRadiusTL":"",
              "borderRadiusTR":"",
              "borderRadiusBL":"",
              "borderRadiusBR":"",
              "borderRadiusSync":true,
              "borderTop":"0",
              "borderBottom":"0",
              "borderLeft":"0",
              "borderRight":"0",
              "borderSync":true,
              "borderStyle":"solid"
           }
        }
     ],
     "settings":{
        "bgStyle":"s",
        "bgGradient":{
           "type":"linear",
           "position":"center",
           "angle":0,
           "color1":"",
           "color1location":0,
           "color2":"",
           "color2location":100
        },
        "contentWidth":1,
        "width":"",
        "bgColor":"",
        "bgImage":"",
        "bgPosition":"",
        "marginTop":"",
        "marginBottom": "",
        "marginLeft": "",
        "marginRight": "",
        "marginSync": false,
        "customClass":"",
        "shadow":"",
        "paddingTop":"",
        "paddingBottom":"",
        "paddingLeft":"",
        "paddingRight":"",
        "paddingSync":true,
        "borderRadius":"",
        "borderTop":"0",
        "borderBottom":"0",
        "borderLeft":"0",
        "borderRight":"0",
        "borderSync":true,
        "borderStyle":"solid",
        "borderRadiusTL":"",
        "borderRadiusTR":"",
        "borderRadiusBL":"",
        "borderRadiusBR":"",
        "borderRadiusSync":true
     }
  }
]';

$seedprod_lite_block_templates = '
 {
  "document":{
      "bgStyle": "s",
      "bgGradient":{ "type": "linear","position": "center", "angle": 0,"color1":"","color1location":0,"color2":"","color2location":100 },
      "bgColor":"#FFFFFF",
      "bgImage":"",
      "bgDimming":0,
      "bgCustomDimming":0,
      "bgCustomDimmingOverlay":"",
      "bgCustomXPositionUnit":"px",
      "bgCustomXPosition":"",
      "bgCustomYPositionUnit":"px",
      "bgCustomYPosition":"",
      "bgCustomAttachment":"",
      "bgCustomRepeat":"",
      "bgCustomSize":"",
      "bgOverlayColor":"",
      "bgPosition":"cover",
      "buttonColor":"#000000",
      "headerColor":"#000000",
      "linkColor":"#FF0000",
      "linkDarkerColor":"#cc0000",
      "textColor":"#272727",
      "textFont":"\'Helvetica Neue\', Arial, sans-serif",
      "textFontVariant":"400",
      "headerFont":"\'Helvetica Neue\', Arial, sans-serif",
      "headerFontVariant":"400",
      "contentPosition":"1",
      "customCss":"",
      "headCss":"",
      "mobileCss":"",
      "placeholderCss":"",
      "useVideoBg":false,
      "useVideoBgUrl":"",
      "useSlideshowBg": false,
      "useSlideshowImgs": [""]
   },
   "row":{
      "bgStyle": "s",
      "bgGradient":{ "type": "linear","position": "center", "angle": 0,"color1":"","color1location":0,"color2":"","color2location":100 },
      "colGutter": 0,
      "contentWidth":2,
      "width":"",
      "bgColor":"",
      "bgImage":"",
      "bgDimming":0,
      "bgDimmingOverlay":"",
      "bgPosition":"",
      "bgCustomDimming":0,
      "bgCustomDimmingOverlay":"",
      "bgCustomXPositionUnit":"px",
      "bgCustomXPosition":"",
      "bgCustomYPositionUnit":"px",
      "bgCustomYPosition":"",
      "bgCustomAttachment":"",
      "bgCustomRepeat":"",
      "bgCustomSize":"",
      "bgCustomSizeWidthUnit":"%",
      "bgCustomSizeWidth":"100",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "shadow":"",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadiusTL": "",
      "borderRadiusTR": "",
      "borderRadiusBL": "",
      "borderRadiusBR": "",
      "borderRadiusSync":true,
      "borderTop": "0",
      "borderBottom": "0",
      "borderLeft": "0",
      "borderRight": "0",
      "borderSync": true,
      "borderStyle":"solid",
      "hideOnDesktop": false,
      "hideOnMobile": false,
      "alignType":"s",
      "display":"",
      "flexDirection":"row",
      "justifyContent":"",
      "alignItems":"",
      "cssPosition":"",
      "offsetTop":"",
      "offsetRight":"",
      "offsetBottom":"",
      "offsetLeft":"",
      "zIndex":"",
      "overflow":"",
      "shapeDivider":"t",
      "bottomShapeType":"",
      "bottomShapeColor":"",
      "bottomshapewidth":100,
      "bottomshapeheight":"",
      "bottomflip":false,
      "bottomfront":false,
      "topShapeType":"",
      "topShapeColor":"",
      "topshapewidth":100,
      "topshapeheight":"",
      "topflip":false,
      "topfront":false
   },
   "section":{
      "bgStyle": "s",
      "bgGradient":{ "type": "linear","position": "center", "angle": 0,"color1":"","color1location":0,"color2":"","color2location":100 },
      "contentWidth":1,
      "width":"",
      "bgColor":"",
      "bgImage":"",
      "bgPosition":"",
      "bgDimming":0,
      "bgDimmingOverlay":"",
      "bgCustomDimming":0,
      "bgCustomDimmingOverlay":"",
      "bgCustomXPositionUnit":"px",
      "bgCustomXPosition":"",
      "bgCustomYPositionUnit":"px",
      "bgCustomYPosition":"",
      "bgCustomAttachment":"",
      "bgCustomRepeat":"",
      "bgCustomSize":"",
      "bgCustomSizeWidthUnit":"%",
      "bgCustomSizeWidth":"100",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "shadow":"",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadiusTL": "",
      "borderRadiusTR": "",
      "borderRadiusBL": "",
      "borderRadiusBR": "",
      "borderRadiusSync":true,
      "borderTop": "0",
      "borderBottom": "0",
      "borderLeft": "0",
      "borderRight": "0",
      "borderSync": true,
      "borderStyle":"solid",
      "shapeDivider":"t",
      "bottomShapeType":"",
      "bottomShapeColor":"",
      "bottomshapewidth":100,
      "bottomshapeheight":"",
      "bottomflip":false,
      "bottomfront":false,
      "topShapeType":"",
      "topShapeColor":"",
      "topshapewidth":100,
      "topshapeheight":"",
      "topflip":false,
      "topfront":false,
      "hideOnDesktop": false,
      "hideOnMobile": false
   },
   "col":{
    "bgStyle": "s",
    "bgGradient":{ "type": "linear","position": "center", "angle": 0,"color1":"","color1location":0,"color2":"","color2location":100 },
    "colWidth":"",
    "bgColor":"",
    "bgImage":"",
    "bgPosition":"",
    "bgDimming":0,
    "bgDimmingOverlay":"",
    "bgCustomDimming":0,
    "bgCustomDimmingOverlay":"",
    "bgCustomXPositionUnit":"px",
    "bgCustomXPosition":"",
    "bgCustomYPositionUnit":"px",
    "bgCustomYPosition":"",
    "bgCustomAttachment":"",
    "bgCustomRepeat":"",
    "bgCustomSize":"",
    "bgCustomSizeWidthUnit":"%",
    "bgCustomSizeWidth":"100",
    "marginTop": "",
    "marginBottom": "",
    "marginLeft": "",
    "marginRight": "",
    "marginSync": false,
    "marginTop_mobile": "",
    "marginBottom_mobile": "",
    "marginLeft_mobile": "",
    "marginRight_mobile": "",
    "marginSync_mobile": false,
    "customClass":"",
    "shadow":"",
    "shadowColor":"",
    "shadowHorizontal":0,
    "shadowVertical":0,
    "shadowBlur":3,
    "shadowSpread":0,
    "shadowPosition":"outline",
    "paddingTop": "",
    "paddingBottom": "",
    "paddingLeft": "",
    "paddingRight": "",
    "paddingSync": true,
    "paddingTop_mobile": "",
    "paddingBottom_mobile": "",
    "paddingLeft_mobile": "",
    "paddingRight_mobile": "",
    "paddingSync_mobile": true,
    "borderRadiusTL": "",
    "borderRadiusTR": "",
    "borderRadiusBL": "",
    "borderRadiusBR": "",
    "borderRadiusSync":true,
    "borderTop": "0",
    "borderBottom": "0",
    "borderLeft": "0",
    "borderRight": "0",
    "borderSync": true,
    "borderStyle":"solid",
    "alignType":"s",
    "display":"",
    "flexDirection":"column",
    "justifyContent":"",
    "alignItems":"",
    "cssPosition":"",
    "offsetTop":"",
    "offsetRight":"",
    "offsetBottom":"",
    "offsetLeft":"",
    "zIndex":"",
    "overflow":"",
    "shapeDivider":"t",
    "bottomShapeType":"",
    "bottomShapeColor":"",
    "bottomshapewidth":100,
    "bottomshapeheight":"",
    "bottomflip":false,
    "bottomfront":false,
    "topShapeType":"",
    "topShapeColor":"",
    "topshapewidth":100,
    "topshapeheight":"",
    "topflip":false,
    "topfront":false,
    "hideOnDesktop": false,
    "hideOnMobile": false
 },
   "icon":{
     "icon":"fas fa-angle-double-down",
     "color":"",
     "fontSize":"48",
     "align":"center",
     "textShadow":"",
     "textshadowColor":"",
     "textshadowHorizontal":0,
     "textshadowVertical":0,
     "textshadowBlur":3,
     "textshadowSpread":0,
     "textshadowPosition":"outline",
     "marginTop": "",
     "marginBottom": "",
     "marginLeft": "",
     "marginRight": "",
     "marginSync": false,
     "marginTop_mobile": "",
     "marginBottom_mobile": "",
     "marginLeft_mobile": "",
     "marginRight_mobile": "",
     "marginSync_mobile": false,
     "customClass":"",
     "paddingTop": "",
     "paddingBottom": "",
     "paddingLeft": "",
     "paddingRight": "",
     "paddingSync": true,
     "paddingTop_mobile": "",
     "paddingBottom_mobile": "",
     "paddingLeft_mobile": "",
     "paddingRight_mobile": "",
     "paddingSync_mobile": true,
     "hideOnDesktop": false,
     "hideOnMobile": false
   },
   "starrating":{
    "label":"",
    "scale":"5",
    "rating":"5",
    "iconSize":"24",
    "spaceBetween":"",
    "align":"center",
    "color":"#fdd835",
    "textColor":"",
    "font": "",
    "fontVariant": "",
    "fontSize": "",
    "fontSize_mobile": "",
    "lineHeight": "",
    "lineHeight_mobile": "",
    "letterSpacing": "",
    "letterSpacing_mobile": "",
    "typographyBold": "",
    "typographyItalic": "",
    "typographyUnderline": "",
    "typographyLetterCase": "",
    "textShadow":"",
    "marginTop": "",
    "marginBottom": "",
    "marginLeft": "",
    "marginRight": "",
    "marginSync": false,
    "marginTop_mobile": "",
    "marginBottom_mobile": "",
    "marginLeft_mobile": "",
    "marginRight_mobile": "",
    "marginSync_mobile": false,
    "customClass":"",
    "paddingTop": "",
    "paddingBottom": "",
    "paddingLeft": "",
    "paddingRight": "",
    "paddingSync": true,
    "paddingTop_mobile": "",
    "paddingBottom_mobile": "",
    "paddingLeft_mobile": "",
    "paddingRight_mobile": "",
    "paddingSync_mobile": true,
    "hideOnDesktop": false,
    "hideOnMobile": false
  },
  "testimonial":{
    "items": [{ "img": "", "txt": "\"This is the greatest thing since sliced bread!\"","name": "John Smith", "title": "CEO" }],
    "align": "left",
    "navColor":"d",
    "commentBubble":true,
    "bubbleColor": "",
    "autoPlay":true,
    "speed":5,
    "marginTop": "",
    "marginBottom": "",
    "marginLeft": "",
    "marginRight": "",
    "marginSync": false,
    "marginTop_mobile": "",
    "marginBottom_mobile": "",
    "marginLeft_mobile": "",
    "marginRight_mobile": "",
    "marginSync_mobile": false,
    "customClass":"",
    "paddingTop": "",
    "paddingBottom": "",
    "paddingLeft": "",
    "paddingRight": "",
    "paddingSync": true,
    "paddingTop_mobile": "",
    "paddingBottom_mobile": "",
    "paddingLeft_mobile": "",
    "paddingRight_mobile": "",
    "paddingSync_mobile": true,
    "textColor": "#444444",
    "font": "",
    "fontVariant": "",
    "fontSize": "",
    "fontSize_mobile": "",
    "lineHeight": "",
    "lineHeight_mobile": "",
    "letterSpacing": "",
    "letterSpacing_mobile": "",
    "typographyBold": "",
    "typographyItalic": true,
    "typographyUnderline": "",
    "typographyLetterCase": "",
    "nameColor": "",
    "namefont": "",
    "namefontVariant": "",
    "namefontSize": "",
    "namefontSize_mobile": "",
    "namelineHeight": "",
    "namelineHeight_mobile": "",
    "nameletterSpacing": "",
    "nameletterSpacing_mobile": "",
    "nametypographyBold": "",
    "nametypographyItalic": "",
    "nametypographyUnderline": "",
    "nametypographyLetterCase": "",
    "hideOnDesktop": false,
    "hideOnMobile": false
   },
   "imagecarousel":{
    "showLightboxGallery":false,
    "items": [{ "img": "", "name": "", "title": "CEO" }],
    "align": "center",
    "captionalign":"center",
    "showCaption": false,
    "navColor":"d",
    "autoPlay":true,
    "speed":5,
    "marginTop": "",
    "marginBottom": "",
    "marginLeft": "",
    "marginRight": "",
    "marginSync": false,
    "marginTop_mobile": "",
    "marginBottom_mobile": "",
    "marginLeft_mobile": "",
    "marginRight_mobile": "",
    "marginSync_mobile": false,
    "customClass":"",
    "paddingTop": "",
    "paddingBottom": "",
    "paddingLeft": "",
    "paddingRight": "",
    "paddingSync": true,
    "paddingTop_mobile": "",
    "paddingBottom_mobile": "",
    "paddingLeft_mobile": "",
    "paddingRight_mobile": "",
    "paddingSync_mobile": true,
    "textColor": "",
    "captionColor": "",
    "captionfont": "",
    "captionfontVariant": "",
    "captionfontSize": "",
    "captionfontSize_mobile": "",
    "captionlineHeight": "",
    "captionlineHeight_mobile": "",
    "captionletterSpacing": "",
    "captionletterSpacing_mobile": "",
    "captiontypographyBold": "",
    "captiontypographyItalic": "",
    "captiontypographyUnderline": "",
    "captiontypographyLetterCase": "",
    "shadow": "",
    "imageBorderRadius": "",
    "imageBorderTop": "0",
    "imageBorderBottom": "0",
    "imageBorderLeft": "0",
    "imageBorderRight": "0",
    "imageBorderSync": true,
    "imageBorderStyle":"solid",
    "imageBorderColor": "",
    "blockTemplateId": false,
    "hideOnDesktop": false,
    "hideOnMobile": false
   },
   "feature":{
    "showLightboxGallery":false,
    "tag": "h2",
    "icon":"",
    "iconColor":"",
    "textColor": "",
    "headerColor": "",
    "iconFontSize":"38",
    "headerTxt": "My Feature or Benefit",
    "layout": "image",
    "txt": "Description",
    "width": "",
    "height": "",
    "align": "left",
    "altTxt": "",
    "src": "",
    "unit":"px",
    "shadowColor":"",
    "shadowHorizontal":0,
    "shadowVertical":0,
    "shadowBlur":3,
    "shadowSpread":0,
    "shadowPosition":"outline",
    "marginTop": "",
    "marginBottom": "",
    "marginLeft": "",
    "marginRight": "",
    "marginSync": false,
    "marginTop_mobile": "",
    "marginBottom_mobile": "",
    "marginLeft_mobile": "",
    "marginRight_mobile": "",
    "marginSync_mobile": false,
    "customClass":"",
    "paddingTop": "",
    "paddingBottom": "",
    "paddingLeft": "",
    "paddingRight": "",
    "paddingSync": true,
    "paddingTop_mobile": "",
    "paddingBottom_mobile": "",
    "paddingLeft_mobile": "",
    "paddingRight_mobile": "",
    "paddingSync_mobile": true,
    "font": "",
    "fontVariant": "",
    "fontSize": "",
    "fontSize_mobile": "",
    "lineHeight": "",
    "lineHeight_mobile": "",
    "letterSpacing": "",
    "letterSpacing_mobile": "",
    "typographyBold": "",
    "typographyItalic": "",
    "typographyUnderline": "",
    "typographyLetterCase": "",
    "headerfont": "",
    "headerfontVariant": "",
    "headerfontSize": "",
    "headerfontSize_mobile": "",
    "headerlineHeight": "",
    "headerlineHeight_mobile": "",
    "headerletterSpacing": "",
    "headerletterSpacing_mobile": "",
    "headertypographyBold": "",
    "headertypographyItalic": "",
    "headertypographyUnderline": "",
    "headertypographyLetterCase": "",
    "hideOnDesktop": false,
    "hideOnMobile": false
   },
   "iconfeature":{
    "tag": "h2",
    "icon":"fas fa-check",
    "iconColor":"",
    "headerColor": "",
    "textColor": "",
    "iconFontSize":"38",
    "headerTxt": "My Feature or Benefit",
    "layout": "icon",
    "txt": "Description",
    "width": "200",
    "height": "",
    "align": "left",
    "altTxt": "",
    "src": "",
    "unit":"px",
    "marginTop": "",
    "marginBottom": "",
    "marginLeft": "",
    "marginRight": "",
    "marginSync": false,
    "marginTop_mobile": "",
    "marginBottom_mobile": "",
    "marginLeft_mobile": "",
    "marginRight_mobile": "",
    "marginSync_mobile": false,
    "customClass":"",
    "paddingTop": "",
    "paddingBottom": "",
    "paddingLeft": "",
    "paddingRight": "",
    "paddingSync": true,
    "paddingTop_mobile": "",
    "paddingBottom_mobile": "",
    "paddingLeft_mobile": "",
    "paddingRight_mobile": "",
    "paddingSync_mobile": true,
    "font": "",
    "fontVariant": "",
    "fontSize": "",
    "fontSize_mobile": "",
    "lineHeight": "",
    "lineHeight_mobile": "",
    "letterSpacing": "",
    "letterSpacing_mobile": "",
    "typographyBold": "",
    "typographyItalic": "",
    "typographyUnderline": "",
    "typographyLetterCase": "",
    "headerfont": "",
    "headerfontVariant": "",
    "headerfontSize": "",
    "headerfontSize_mobile": "",
    "headerlineHeight": "",
    "headerlineHeight_mobile": "",
    "headerletterSpacing": "",
    "headerletterSpacing_mobile": "",
    "headertypographyBold": "",
    "headertypographyItalic": "",
    "headertypographyUnderline": "",
    "headertypographyLetterCase": "",
    "hideOnDesktop": false,
    "hideOnMobile": false
   },
   "header":{
      "headerTxt": "My Awesome Headline",
      "tag": "h1",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "center",
      "align_mobile": "center",
      "typographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "animatedheadline":{
      "beforeHeaderTxt": "Before text",
      "headerTxt": "My Awesome Headline",
      "headerBiggerTxt": "My Awesome\nBigger Headline",
      "afterHeaderTxt": "After text",
      "styleType":"highlight",
      "shapeType":"circle",
      "animationType":"typing",
      "infiniteLoop":true,
      "animationDuration":1200,
      "animationDelay":8000,
      "strokeColor":"",
      "tag": "h1",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "center",
      "typographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "seedprodgallery":{
      "items": [{ "img": "","imgdata":[],"imagesid":[], "name": "", "title": "CEO" }],
      "singleitems": [{ "img": "","imgdata":[],"imagesid":[], "name": "" }],
      "align": "center",
      "captionalign":"center",
      "bgOverlay": false,
      "overlay_title":"",
      "overlay_desc":"",
      "galleryType":"single",
      "galleryLayout":"grid",
      "galleryimg":"",
      "galleryimgobj":[],
      "galleryimgid":[],
      "galleryimgdata":[],
      "rowHeight":"100",
      "navColor":"d",
      "lazyLoad":true,
      "columns":3,
      "colSpacing":"1",
      "galleryLink":"",
      "customurl":"",
      "aspect_ratio":"1:1",
      "image_size":"medium",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "textColor": "",
      "captionColor": "",
      "captionfont": "",
      "captionfontVariant": "",
      "captionfontSize": "",
      "captionfontSize_mobile": "",
      "captionlineHeight": "",
      "captionlineHeight_mobile": "",
      "captionletterSpacing": "",
      "captionletterSpacing_mobile": "",
      "captiontypographyBold": "",
      "captiontypographyItalic": "",
      "captiontypographyUnderline": "",
      "captiontypographyLetterCase": "",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "typographyLetterCase": "",
      "overlayColor": "",
      "overlayfont": "",
      "overlayfontVariant": "",
      "overlayfontSize": "",
      "overlayfontSize_mobile": "",
      "overlaylineHeight": "",
      "overlaylineHeight_mobile": "",
      "overlayletterSpacing": "",
      "overlayletterSpacing_mobile": "",
      "overlaytypographyBold": "",
      "overlaytypographyItalic": "",
      "overlaytypographyUnderline": "",
      "overlaytypographyLetterCase": "",
      "headerColor":"",
      "headerOpenColor":"",
      "headerfont": "",
      "headerfontVariant": "",
      "headerfontSize": "",
      "headerfontSize_mobile": "",
      "headerlineHeight": "",
      "headerlineHeight_mobile": "",
      "headerletterSpacing": "",
      "headerletterSpacing_mobile": "",
      "headertypographyBold": "",
      "headertypographyItalic": "",
      "headertypographyUnderline": "",
      "headertypographyLetterCase": "",
      "overlayColor":"#ffffff",
      "overlayBgColor":"#000000",
      "shadow": "",
      "imageBorderRadius": "",
      "imageBorderTop": "0",
      "imageBorderBottom": "0",
      "imageBorderLeft": "0",
      "imageBorderRight": "0",
      "imageBorderSync": true,
      "imageBorderStyle":"solid",
      "imageBorderColor": "",
      "blockTemplateId": false,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "seedprodbasicgallery":{
      "items": [{ "img": "","imgdata":[],"imagesid":[], "name": "", "title": "CEO" }],
      "singleitems": [{ "img": "","imgdata":[],"imagesid":[], "name": "" }],
      "order_by":"",
      "align": "center",
      "captionalign":"center",
      "bgOverlay": true,
      "overlay_title":"",
      "overlay_desc":"",
      "galleryType":"single",
      "lightboxEffect":"no",
      "galleryLayout":"grid",
      "galleryimg":"",
      "galleryimgobj":[],
      "galleryimgid":[],
      "galleryimgdata":[],
      "rowHeight":"100",
      "navColor":"d",
      "lazyLoad":true,
      "columns":3,
      "colSpacing":"1",
      "galleryLink":"none",
      "customurl":"",
      "aspect_ratio":"1:1",
      "image_size":"medium",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "textColor": "",
      "captionColor": "",
      "captionfont": "",
      "captionfontVariant": "",
      "captionfontSize": "",
      "captionfontSize_mobile": "",
      "captionlineHeight": "",
      "captionlineHeight_mobile": "",
      "captionletterSpacing": "",
      "captionletterSpacing_mobile": "",
      "captiontypographyBold": "",
      "captiontypographyItalic": "",
      "captiontypographyUnderline": "",
      "captiontypographyLetterCase": "",
      "shadow": "",
      "imageBorderRadius": "",
      "imageBorderTop": "0",
      "imageBorderBottom": "0",
      "imageBorderLeft": "0",
      "imageBorderRight": "0",
      "imageBorderSync": true,
      "imageBorderStyle":"solid",
      "imageBorderColor": "",
      "blockTemplateId": false,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "button":{
      "action": "link",
      "link": "",
      "openNewWindow": false,
      "noFollow": false,
      "btnTxt": "Call To Action",
      "btnStyle": "",
      "btnSubTxt": "",
      "btnSubTextSize": "",
      "textColor": "",
      "bgColor": "",
      "buttonTextColor":"",
      "bgColorHover":"",
      "buttonTextHoverColor":"",
      "buttonNormalStyle":"s",
      "buttonNormalBGtype":"radial",
      "buttonNormalBGposition":"",
      "buttonHoverStyle":"s",
      "buttonHoverBGtype":"radial",
      "buttonHoverBGposition":"",
      "btnStyleHover":"",
      "btnPaddingTop": "16",
      "btnPaddingLeft": "20",
      "btnSize":"4",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "4",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "22",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "center",
      "align_mobile": "center",
      "typographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "text":{
      "editortxt":"code",
      "txt": "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam commodo velit ex, non ultrices leo auctor at. Integer blandit ex velit, vel aliquam sem tempor eu. Pellentesque sem tortor, elementum et nisi sed, convallis pharetra lorem. Aenean rhoncus rhoncus ex, in dictum massa dictum et. Morbi at nisl fermentum, condimentum tortor a, laoreet leo. Curabitur laoreet diam a metus tincidunt, sed dapibus orci venenatis.",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "align_mobile": "left",
      "typographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "facebooklike":{
      "buttonType":"like",
      "layoutType":"standard",
      "buttonSize":"small",
      "shareButton":false,
      "targetUrl":"currentpage",
      "targetUrlFormat":"plainpermalink",     
      "customlinkurl":"",
      "align": "left",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "facebookcomments":{
      "orderBy" :"social",
      "lazyLoad" :false,
      "colorScheme" : "dark",
      "numComments" : "5",
      "targetUrl":"currentpage",
      "targetUrlFormat":"plainpermalink",     
      "customlinkurl":"",
      "align": "center",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "facebookpage":{
      "layoutPage":"timeline",
      "multiLayoutPage":["timeline"],
      "smallHeader" : false,
      "coverPhoto" : false,
      "profilePhoto" : true,
      "hideCTA" : true,
      "height" : "500",   
      "customlinkurl":"https://www.facebook.com/seedprodwp/",
      "align": "center",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "facebookembed":{
      "embedType":"post",
      "fullPost" : true,
      "fullScreen" : true,
      "autoPlay" : true,
      "captions" : true,
      "parentComment" : true,
      "height" : "500",   
      "postlinkurl":"https://www.facebook.com/seedprodwp/posts/1788470497975496",
      "videolinkurl":"https://business.facebook.com/seedprodwp/videos/226940179165922/",
      "commentlinkurl":"https://www.facebook.com/zuck/posts/10102577175875681?comment_id=1193531464007751&reply_comment_id=654912701278942",
      "align": "center",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "twitterembedtweet":{    
      "align": "left",
      "tweeterid":"1385250840898850816",
      "colorScheme":"light",
      "width":"350",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "lang":"en",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "twitterembedtimeline":{
      "align": "left",
      "tweeterid":"seedprod",
      "colorScheme":"light",
      "width":"350",
      "height":"350",
      "hideHeader": false,
      "hideFooter": true,
      "hideBorders": false,
      "transparent": false,
      "hideScrollbar": false,
      "showReplies":false,
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "lang":"en",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "sitelogo":{
      "unit":"px",
      "height":"",
      "width":"",
      "align": "left",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "2",
      "paddingBottom": "2",
      "paddingLeft": "0",
      "paddingRight": "0",
      "paddingSync": true,
      "paddingTop_mobile": "2",
      "paddingBottom_mobile": "2",
      "paddingLeft_mobile": "0",
      "paddingRight_mobile": "0",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "twittertweetbutton":{
      "tweetUrl":"https://twitter.com/seedprod",
      "buttonSize":"small",
      "tweetText":"",
      "tweetHashTag":"", 
      "viaHandle":"", 
      "relatedTweet":"",   
      "align": "left",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "lang":"en",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "twitterfollowbutton":{
      "screenName":"seedprod",
      "buttonSize":"small",
      "showScreenName":true,
      "showCount":false, 
      "align": "left",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "lang":"en",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "contactform":{
      "formId":"",
      "formTitle": "false",
      "formDescription": "false",
      "textColor":"",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "align": "center",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "typographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "giveaway":{
      "giveawayId":"",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "align": "center",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "image":{
      "linktype":"custom",
      "link": "",
      "openNewWindow": false,
      "noFollow": false,
      "unit":"px",
      "src": "",
      "altTxt": "",
      "link": "",
      "width": "",
      "height": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "imagePadding": "",
      "align": "center",
      "align_mobile": "center",
      "shadow": "",
      "imageBorderRadius": "",
      "imageBorderTop": "0",
      "imageBorderBottom": "0",
      "imageBorderLeft": "0",
      "imageBorderRight": "0",
      "imageBorderSync": true,
      "imageBorderStyle":"solid",
      "imageBorderColor": "",
      "blockTemplateId":false,
      "radiusunit":"px",
      "hideOnDesktop": false,
      "imghiddenwidth": "",
      "imghiddenheight": "",
      "borderRadiusSync":true,
      "shadowColor":"#000000",
      "shadowSpread":"-20",
      "shadowHorizontal":"0",
      "borderRadiusTL":"",
      "borderRadiusTR":"",
      "borderRadiusBL":"",
      "borderRadiusBR":"",
      "shadowVertical":"20",
      "shadowBlur":"20",
      "shadowPosition":"outline",
      "objectfit":"",
      "hideOnMobile": false
    },
    "divider":{
      "style": "solid",
      "width": "90",
      "height": "1",
      "color": "",
      "align": "center",
      "align_mobile": "center",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "10",
      "paddingBottom": "10",
      "paddingLeft": "0",
      "paddingRight": "0",
      "paddingSync": false,
      "paddingTop_mobile": "10",
      "paddingBottom_mobile": "10",
      "paddingLeft_mobile": "0",
      "paddingRight_mobile": "0",
      "paddingSync_mobile": false,
      "shadow": "",
      "addelement":"",
      "elementText":"SeedProd",
      "elementTextTag":"span",
      "elementIcon":"fas fa-check",
      "textColor": "",
      "iconColor": "",
      "headerfont": "",
      "headerfontVariant": "",
      "headerfontSize": "",
      "headerfontSize_mobile": "",
      "headerlineHeight": "",
      "headerlineHeight_mobile": "",
      "headerletterSpacing": "",
      "headerletterSpacing_mobile": "",
      "headertypographyBold": "",
      "headertypographyItalic": "",
      "headertypographyUnderline": "",
      "headertypographyLetterCase": "",
      "iconHeight": "15",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "spacer": {
      "height": 60,
      "height_mobile": 60
    },
    "accordion":{
      "spaceBetween":"24",
      "items": [{"txt": "Accordion 1", "details": "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam commodo velit ex, non ultrices leo auctor at."},{"txt": "Accordion 2", "details": "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam commodo velit ex, non ultrices leo auctor at."}],
      "bgColor": "",
      "dividerColor": "",
      "textColor": "",
      "iconColor": "",
      "openIconColor": "",
      "closedIcon": "fas fa-plus",
      "openIcon": "fas fa-minus",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "typographyLetterCase": "",
      "headerColor":"",
      "headerOpenColor":"",
      "headerfont": "",
      "headerfontVariant": "",
      "headerfontSize": "",
      "headerfontSize_mobile": "",
      "headerlineHeight": "",
      "headerlineHeight_mobile": "",
      "headerletterSpacing": "",
      "headerletterSpacing_mobile": "",
      "headertypographyBold": "",
      "headertypographyItalic": "",
      "headertypographyUnderline": "",
      "headertypographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "anchor": {
      "name": ""
    },
    "searchform": {
      "align": "center",
      "buttonType":"icon",
      "buttonIconType":"icon1",
      "placeholder":"Search...",
      "buttonText":"Search",
      "size":36,
      "width":"",
      "bgColor":"",
      "searchColor":"",
      "buttonBgColor":"",
      "buttonColor":"",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "googlemaps": {
      "location": "West Palm Beach, FL",
      "zoom": "10",
      "width": "100",
      "height": "",
      "align": "center",
      "shadow":"",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "customhtml":{
      "code": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "shortcode":{
      "shortcode": "",
      "shortcode_placeholder": "",
      "render_shortcode_preview": false,
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true
    },
    "templatetag":{
      "templatetag": "",
      "templatetag_placeholder": "",
      "render_templatetag_preview": false,
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "seedprodtemplateparts":{
      "templateparts" :"",
      "templateresult":"",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "login":{
      "align": "left",
      "redirectUrl": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "rowSpacing": "10",
      "linkColor": "",
      "linkHoverColor": "",
      "loggedInText": "Logged in as {user}",
      "labelRememberme": "Remember Me",
      "labelLostpass": "Lost your password?",
      "labelTextUser": "Username or Email Address",
      "labelTextUserPlaceholder": "",
      "labelTextPass": "Password",
      "labelTextPassPlaceholder": "",
      "labelSpacing": "5",
      "labelTextColor": "",
      "labelTextFont": "",
      "labelTextSize": "",
      "labelTextFontVariant": "",
      "fieldTextColor": "",
      "fieldSize": "md",
      "fieldWidth": "100",
      "fieldTextFontSize": "",
      "fieldPaddingVertical": "6",
      "fieldPaddingHorizontal": "10",
      "fieldTextFont": "",
      "fieldTextFontVariant": "",
      "fieldBGColor": "",
      "fieldBorderColor": "",
      "fieldborderTop": "1",
      "fieldborderBottom": "1",
      "fieldborderLeft": "1",
      "fieldborderRight": "1",
      "fieldBorderRadius": "3",
      "btnText": "Log In",
      "btnTextFontSize": "15",
      "btnTextFont": "",
      "btnTextFontVariant": "",
      "btnTextColor": "",
      "btnSize": "1",
      "btnBgColor": "",
      "btnPaddingVertical": "8",
      "btnPaddingHorizontal": "12",
      "btnBorderRadius": "3",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "video":{
      "type":"youtube",
      "code": "",
      "youtubeUrl": "https://www.youtube.com/watch?v=MUXoqm3VpRo",
      "width": "100",
      "align": "center",
      "align_mobile": "center",
      "shadow":"",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "countdown":{
      "countdownType":"",
      "vtHours":"0",
      "vtMinutes":"30",
      "vtSeconds":"0",
      "action":1,
      "thankyouTxt": "",
      "redirectUrl": "",
      "size":"md",
      "timezone": "' . seedprod_lite_get_default_timezone() . '",
      "endDate": "",
      "endTime": "",
      "endTimestamp": "",
      "bgColor": "",
      "labelColor": "",
      "dayTxt":"Days",
      "hourTxt":"Hours",
      "minuteTxt":"Minutes",
      "secondTxt":"Seconds",
      "spaceBetween":"20",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "center",
      "typographyLetterCase": "uppercase",
      "blockTemplateId":false,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "bulletlist":{
      "layout": "v",
      "spaceBetween":"10",
      "spaceBetween_mobile":"10",
      "items": [{ "icon": "fas fa-check", "txt": "Item 1" }],
      "textColor": "",
      "iconColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "align_mobile": "left",
      "typographyLetterCase": "",
      "blockTemplateId":false,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "businesshours":{
      "rowSpacing":"6",
      "items": [{ "icon": "fas fa-check","txt": "Monday", "daytxt": "Monday" , "timetxt":"9:AM - 6:PM" , "styleday":false,"daycolor":"#ccc","timecolor":"#ccc","bgcolor":"#fff" },
                { "icon": "fas fa-check","txt": "Tuesday", "daytxt": "Tuesday" , "timetxt":"9:AM - 6:PM" , "styleday":false,"daycolor":"#ccc","timecolor":"#ccc","bgcolor":"#fff" },
                { "icon": "fas fa-check","txt": "Wednesday", "daytxt": "Wednesday" , "timetxt":"9:AM - 6:PM" , "styleday":false,"daycolor":"#ccc","timecolor":"#ccc","bgcolor":"#fff" },
                { "icon": "fas fa-check","txt": "Thursday", "daytxt": "Thursday" , "timetxt":"9:AM - 6:PM" , "styleday":false,"daycolor":"#ccc","timecolor":"#ccc","bgcolor":"#fff" },
                { "icon": "fas fa-check","txt": "Friday", "daytxt": "Friday" , "timetxt":"9:AM - 6:PM" , "styleday":false,"daycolor":"#ccc","timecolor":"#ccc","bgcolor":"#fff" },
                { "icon": "fas fa-check","txt": "Saturday", "daytxt": "Saturday" , "timetxt":"9:AM  - 11:AM" , "styleday":false,"daycolor":"#ccc","timecolor":"#ccc","bgcolor":"#fff" },
                { "icon": "fas fa-check","txt": "Sunday", "daytxt": "Sunday" , "timetxt":"Closed" , "styleday":false,"daycolor":"#ccc","timecolor":"#ccc","bgcolor":"#fff" }],
      "textColor": "",
      "timeColor":"",
      "iconColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "shadow": "",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "12",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "typographyLetterCase": "",
      "timealign": "center",
      "timefont": "",
      "timefontVariant": "",
      "timefontSize": "12",
      "timefontSize_mobile": "",
      "timelineHeight": "",
      "timelineHeight_mobile": "",
      "timeletterSpacing": "",
      "timeletterSpacing_mobile": "",
      "timetypographyBold": "",
      "timetypographyItalic": "",
      "timetypographyUnderline": "",
      "timetypographyLetterCase": "",
      "divider":false,
      "dividerStyle":"solid",
      "dividerWeight":"1",
      "stripEffect":false,
      "stripOddColor":"#cccccc",
      "stripEvenColor":"#ffffff",
      "borderRadius": "1",
      "border": "",
      "borderStyle": "solid",
      "borderSize": "",
      "borderColor": "",
      "borderRadiusTL": "",
      "borderRadiusTR": "",
      "borderRadiusBL": "",
      "borderRadiusBR": "",
      "borderRadiusSync":true,
      "borderTop": "0",
      "borderBottom": "0",
      "borderLeft": "0",
      "borderRight": "0",
      "borderSync": true,
      "bgStyle": "s",
      "bgGradient":{ "type": "linear","position": "center", "angle": 0,"color1":"","color1location":0,"color2":"","color2location":100 },
      "bgColor":"",
      "bgImage":"",
      "bgPosition":"",
      "bgDimming":0,
      "bgDimmingOverlay":"",
      "bgCustomDimming":0,
      "bgCustomDimmingOverlay":"",
      "bgCustomXPositionUnit":"px",
      "bgCustomXPosition":"",
      "bgCustomYPositionUnit":"px",
      "bgCustomYPosition":"",
      "bgCustomAttachment":"",
      "bgCustomRepeat":"",
      "bgCustomSize":"",
      "bgCustomSizeWidthUnit":"%",
      "bgCustomSizeWidth":"100",
      "blockTemplateId":false,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "tabbedlayout":{
      "layout": "h",
      "spaceBetween":"6",
      "items": [{ "icon": "fas fa-check", "txt": "Tab 1", "content": "Tab Content"  }],
      "textColor": "",
      "hideTabIcons":true,
      "tabColor":"",
      "tabBGColor":"",
      "iconColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "6",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "typographyLetterCase": "",
      "blockTemplateId":false,
      "headeralign":"left",
      "headerColor":"",
      "headerOpenColor":"",
      "headerfont": "",
      "headerfontVariant": "",
      "headerfontSize": "",
      "headerfontSize_mobile": "",
      "headerlineHeight": "",
      "headerlineHeight_mobile": "",
      "headerletterSpacing": "",
      "headerletterSpacing_mobile": "",
      "headertypographyBold": "",
      "headertypographyItalic": "",
      "headertypographyUnderline": "",
      "headertypographyLetterCase": "",
      "activetabColor":"#333333",
      "activetabBGColor":"",
      "contentpaddingTop": "",
      "contentpaddingBottom": "",
      "contentpaddingLeft": "",
      "contentpaddingRight": "",
      "contentpaddingSync": true,
      "tabpaddingTop": "",
      "tabpaddingBottom": "",
      "tabpaddingLeft": "",
      "tabpaddingRight": "",
      "tabpaddingSync": true,
      "tabBorderRadius":"4",
      "tabBorderStyle":"solid",
      "tabBorderColor":"",
      "tabBorderSync":"true",
      "tabBorderTop": "",
      "tabBorderRight": "",
      "tabBorderBottom": "",
      "tabBorderLeft": "",
      "textBGColor":"",
      "tabContentBorderRadius":"",
      "tabContentBorderStyle":"solid",
      "tabContentBorderColor":"",
      "tabContentBorderSync":"true",
      "tabContentBorderTop": "",
      "tabContentBorderRight": "",
      "tabContentBorderBottom": "",
      "tabContentBorderLeft": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "nav":{
      "layout": "h",
      "menutype":"s",
      "mobileMenu":false,
      "divider":"",
      "navmenu":"",
      "spaceBetween":"20",
      "items": [{ "url": "", "txt": "About","openNewWindow":"","noFollow":"" }],
      "textColor": "",
      "textHoverColor": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "typographyLetterCase": "",
      "menuBackgroundColor": "",
      "submenuTextColor": "",
      "submenuHoverColor": "",
      "submenuBorderRadius": "6",
      "submenuLineHeight": "",
      "submenupaddingTop": "4",
      "submenupaddingBottom": "4",
      "submenupaddingLeft": "4",
      "submenupaddingRight": "4",
      "submenupaddingSync": true,
      "submenuBorderWidth": "",
      "submenuBorderColor": "",
      "subnavshadow": "6",
      "subnavshadowColor":"",
      "subnavshadowHorizontal":0,
      "subnavshadowVertical":0,
      "subnavshadowBlur":3,
      "subnavshadowSpread":0,
      "subnavshadowPosition":"outline",
      "subnavColor": "",
      "subnavHoverColor": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "form":{
      "items": []
    },
    "optinform":{
      "align": "center",
      "items": [
        { "type": "email", "label":"Enter Your Email","txt":"Email","width":"100","required": true,"display": true},
        { "type": "name", "label":"Enter Your Name","txt":"Name","width":"100","required": false, "display": true},
        { "type": "optin_confirm", "label":"Optin Confirmation","txt":"Optin Confirmation","width":"100","required": true,"display": false}
      ],
      "action":"1",
      "redirectUrl":"",
      "thankyouTxt":"Thank You, we\'ll be in touch soon.",
      "btnSize":"3",
      "inputSize":"",
      "bgColor":"",
      "btnWidth":"100",
      "btnTxt":"Submit",
      "btnSubTxt":"",
      "btnPaddingTop": "16",
      "btnPaddingLeft": "20",
      "inputPadding": "8",
      "fieldBGColor": "",
      "fieldTextColor": "",
      "fieldBorderColor": "",
      "fieldborderTop": "1",
      "fieldborderBottom": "1",
      "fieldborderLeft": "1",
      "fieldborderRight": "1",
      "fieldborderSync": true,
      "buttonFontSize": "",
      "beforeIcon":"",
      "afterIcon":"",
      "shadow": "",
      "borderRadius": "3",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "center",
      "typographyLetterCase": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "gap": false,
      "blockTemplateId":false,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "progressbar":{
      "txt": "My Text",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "width": "60",
      "color": "",
      "outerColor": "#F7F7F7",
      "borderRadius": "3",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "center",
      "typographyLetterCase": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "blockTemplateId":false,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "socialprofiles":{
      "iconStyle":"1",
      "iconPadding": 15,
      "iconSize": 24,
      "iconColor": "",
      "size": "md",
      "items": [{ "type": "facebook", "label":"","url":"","icon":"", "color":"" },{ "type": "twitter", "label":"","url":"","icon":"", "color":"" },{ "type": "instagram", "label":"","url":"","icon":"", "color":"" },{ "type": "youtube", "label":"","url":"","icon":"", "color":"" }],
      "spaceBetween": "10",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "align": "center",
      "blockTemplateId":false,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "socialsharing":{
      "size": "sm",
      "items": [{ "type": "facebook", "label":"", "meta":"","url":"" },{ "type": "twitter", "label":"", "meta":"","url":"" }],
      "spaceBetween": "20",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "align": "center",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "pricingtable":{
      "planName": "Enter Your Plan Name",
      "price": "100",
      "currencySymbol": "$",
      "customCurrencySymbol": "",
      "showRegularPrice": true,
      "regularPrice": "150",
      "regularPriceLabel": "Normally",
      "period": "/month",
      "description": "Perfect For Beginners",
      "showTopButton": true,
      "topButtonText": "Call To Action",
      "topButtonLink": "",
      "topButtonLinkOpenNewWindow": false,
      "topButtonLinkNoFollow": false,
      "topButtonStyle": "flat",
      "topButtonBgColor": "",
      "topButtonShadow": "",
      "topButtonLineHeight": "",
      "topbuttonfont": "",
      "topbuttonfontVariant": "",
      "topbuttonfontSize": "16",
      "topbuttonfontSize_mobile": "",
      "topbuttonlineHeight": "",
      "topbuttonlineHeight_mobile": "",
      "topbuttonletterSpacing": "",
      "topbuttonletterSpacing_mobile": "",
      "topbuttontypographyBold": "",
      "topbuttontypographyItalic": "",
      "topbuttontypographyUnderline": "",
      "topbuttontypographyLetterCase": "",
      "topbuttonalign": "center",
      "topButtonSize":"3",
      "topButtonPaddingTop": "15",
      "topButtonPaddingLeft": "35",
      "topButtonBorderRadius": "7",
      "topButtonBeforeIcon": "",
      "topButtonAfterIcon": "",
      "featuresHeader": "",
      "featuresList": [{ "icon": "fas fa-check", "txt": "Features List Item #1" }, { "icon": "fas fa-check", "txt": "Features List Item #2" }],
      "featuresListLayout": "v",
      "featuresListSpaceBetween":"10",
      "featuresListIconColor":"10",
      "featureslistalign": "center",
      "featureslistfontSize": "16",
      "featureslisttypographyBold": "",
      "featureslisttypographyItalic": "",
      "featureslisttypographyUnderline": "",
      "featureslisttypographyLetterCase": "",
      "featureslistfontVariant": "",
      "featureslistfontSize_mobile": "",
      "featureslistlineHeight": "1.5",
      "featureslistlineHeight_mobile": "",
      "featureslistletterSpacing": "",
      "featureslistletterSpacing_mobile": "",
      "featuresListTextColor": "",
      "featuresListBackgroundColor": "#ffffff",
      "featuresListPadding": "10",
      "showBottomButton": true,
      "bottomButtonText": "Call To Action",
      "bottomButtonLink": "",
      "bottomButtonLinkOpenNewWindow": false,
      "bottomButtonLinkNoFollow": false,
      "bottomButtonStyle": "flat",
      "bottomButtonBgColor": "",
      "bottomButtonShadow": "",
      "bottomButtonLineHeight": "",
      "bottombuttonfont": "",
      "bottombuttonfontVariant": "",
      "bottombuttonfontSize": "16",
      "bottombuttonfontSize_mobile": "",
      "bottombuttonlineHeight": "3",
      "bottombuttonlineHeight_mobile": "",
      "bottombuttonletterSpacing": "",
      "bottombuttonletterSpacing_mobile": "",
      "bottombuttontypographyBold": "",
      "bottombuttontypographyItalic": "",
      "bottombuttontypographyUnderline": "",
      "bottombuttontypographyLetterCase": "",
      "bottombuttonalign": "center",
      "bottomButtonSize":"3",
      "bottomButtonPaddingTop": "15",
      "bottomButtonPaddingLeft": "35",
      "bottomButtonBorderRadius": "7",
      "bottomButtonBeforeIcon": "",
      "bottomButtonAfterIcon": "",
      "headerBackgroundColor": "#f3f3f3",
      "headerPadding": "20",
      "plannamealign": "center",
      "plannamefont": "",
      "plannamefontVariant": "",
      "plannamefontSize": "22",
      "plannamefontSize_mobile": "",
      "plannamelineHeight": "",
      "plannamelineHeight_mobile": "",
      "plannameletterSpacing": "",
      "plannameletterSpacing_mobile": "",
      "plannametypographyBold": "",
      "plannametypographyItalic": "",
      "plannametypographyUnderline": "",
      "plannametypographyLetterCase": "",
      "planNameTextColor": "",
      "regularpricealign": "center",
      "regularpricefont": "",
      "regularpricefontVariant": "",
      "regularpricefontSize": "16",
      "regularpricefontSize_mobile": "",
      "regularpricelineHeight": "",
      "regularpricelineHeight_mobile": "",
      "regularpriceletterSpacing": "",
      "regularpriceletterSpacing_mobile": "",
      "regularpricetypographyBold": "",
      "regularpricetypographyItalic": "",
      "regularpricetypographyUnderline": "",
      "regularpricetypographyLetterCase": "",
      "regularPriceTextColor": "#9E9E9E",
      "descriptionalign": "center",
      "descriptionfont": "",
      "descriptionfontVariant": "",
      "descriptionfontSize": "16",
      "descriptionfontSize_mobile": "",
      "descriptionlineHeight": "",
      "descriptionlineHeight_mobile": "",
      "descriptionletterSpacing": "",
      "descriptionletterSpacing_mobile": "",
      "descriptiontypographyBold": "",
      "descriptiontypographyItalic": "",
      "descriptiontypographyUnderline": "",
      "descriptiontypographyLetterCase": "",
      "descriptionTextColor": "",
      "pricealign": "center",
      "pricefont": "",
      "pricefontVariant": "",
      "pricefontSize": "70",
      "pricefontSize_mobile": "",
      "pricelineHeight": "",
      "pricelineHeight_mobile": "",
      "priceletterSpacing": "",
      "priceletterSpacing_mobile": "",
      "pricetypographyBold": true,
      "pricetypographyItalic": "",
      "pricetypographyUnderline": "",
      "pricetypographyLetterCase": "",
      "priceTextColor": "",
      "pricesuperscriptalign": "center",
      "pricesuperscriptfont": "",
      "pricesuperscriptfontVariant": "",
      "pricesuperscriptfontSize": "14",
      "pricesuperscriptfontSize_mobile": "",
      "pricesuperscriptlineHeight": "",
      "pricesuperscriptlineHeight_mobile": "",
      "pricesuperscriptletterSpacing": "",
      "pricesuperscriptletterSpacing_mobile": "",
      "pricesuperscripttypographyBold": "",
      "pricesuperscripttypographyItalic": "",
      "pricesuperscripttypographyUnderline": "",
      "pricesuperscripttypographyLetterCase": "",
      "priceSuperScriptTextColor": "",
      "priceSuperScriptTop": "-2.5",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "4",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "blockBorderRadius": "",
      "blockBorderTop": "1",
      "blockBorderBottom": "1",
      "blockBorderLeft": "1",
      "blockBorderRight": "1",
      "blockBorderSync": true,
      "blockBorderStyle":"solid",
      "blockBorderColor": "#f3f3f3",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "wcaddtocart":{
      "productId": "",
      "directToCheckout": false,
      "btnTxt": "Add To Cart",
      "btnStyle": "",
      "btnSubTxt": "",
      "btnSubTextSize": "",
      "textColor": "#ffffff",
      "bgColor": "",
      "btnPaddingTop": "16",
      "btnPaddingLeft": "20",
      "btnSize":"4",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "4",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "22",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "center",
      "typographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "wccart":{
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "headerColor": "",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "typographyLetterCase": "",
      "align": "",
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "btnShadow": "",
      "btnLineHeight": "",
      "fieldBGColor": "",
      "fieldTextColor": "",
      "fieldBorderColor": "",
      "fieldborderTop": "1",
      "fieldborderRight": "1",
      "fieldborderBottom": "1",
      "fieldborderLeft": "1",
      "fieldborderSync": "true",
      "alertInfoHlColor": "",
      "alertErrorHlColor": "",
      "alertSuccessHlColor": "",
      "cartFieldBorderColor": "",
      "cartborderTop": "1",
      "cartborderRight": "1",
      "cartborderBottom": "1",
      "cartborderLeft": "1",
      "cartborderSync": "true",
      "cartBorderRadius": "",
      "cartBgColor": "",
      "cartTextColor": "",
      "cartFont": "",
      "cartFontVariant": "",
      "cartHeaderBgColor": "",
      "cartHeaderFont": "",
      "cartHeaderFontVariant": "",
      "cartHeaderColor": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
  "wccheckout":{
      "css": "",
      "layoutColumns": "2",
      "headerColor": "",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "typographyLetterCase": "",
      "align": "",
      "fieldBGColor": "",
      "fieldTextColor": "",
      "fieldBorderColor": "",
      "fieldborderTop": "1",
      "fieldborderRight": "1",
      "fieldborderBottom": "1",
      "fieldborderLeft": "1",
      "fieldborderSync": "true",
      "borderRadius": "",
      "labelColor": "",
      "labelfont": "",
      "labelfontVariant": "",
      "labelfontSize": "",
      "labelfontSize_mobile": "",
      "labellineHeight": "",
      "labellineHeight_mobile": "",
      "labelletterSpacing": "",
      "labelletterSpacing_mobile": "",
      "labeltypographyBold": "",
      "labeltypographyItalic": "",
      "labeltypographyUnderline": "",
      "labeltypographyLetterCase": "",
      "labelalign": "",
      "rowSpacing": "6",
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "btnShadow": "",
      "btnLineHeight": "",
      "alertInfoHlColor": "",
      "alertErrorHlColor": "",
      "alertSuccessHlColor": "",
      "cartFieldBorderColor": "",
      "cartborderTop": "1",
      "cartborderRight": "1",
      "cartborderBottom": "1",
      "cartborderLeft": "1",
      "cartborderSync": "true",
      "cartBorderRadius": "",
      "cartBgColor": "",
      "cartTextColor": "",
      "cartFont": "",
      "cartFontVariant": "",
      "cartHeaderBgColor": "",
      "cartHeaderFont": "",
      "cartHeaderFontVariant": "",
      "cartHeaderColor": "",
      "paymentBgColor": "",
      "paymentTextColor": "#333",
      "paymentFont": "",
      "paymentFontVariant": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },

 "wccustomproductsgrid":{
      "columns": "4",
      "pagination": false,
      "limit": "-1",
      "showItemsCount": false,
      "showOrderBy": false,
      "selectProductIds": false,
      "productIds": [],
      "selectProductSkus": false,
      "productSkus": [],
      "selectCategories": false,
      "productCategories": [],
      "queryCategoriesOperator": "IN",
      "selectTags": false,
      "productTags": [],
      "queryTagsOperator": "IN",
      "selectGroup": false,
      "productGroups": "",
      "selectByVisibility": false,
      "productVisibility": "",
      "queryByAttribute": false,
      "queryAttribute": "",
      "queryAttributeTerms": [],
      "queryTermsOperator": "IN",
      "querySource": "all_products",
      "queryInclude": "",
      "queryIncludeBy": "",
      "queryIncludeTerm": "",
      "queryExclude": "",
      "queryExcludeBy": "",
      "queryExcludeTerm": "",
      "queryOrderBy": [],
      "queryOrder": "ASC",
      "align": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "descriptionfont": "",
      "descriptionfontVariant": "",
      "descriptionfontSize": "",
      "descriptionfontSize_mobile": "",
      "descriptionlineHeight": "",
      "descriptionlineHeight_mobile": "",
      "descriptionletterSpacing": "",
      "descriptionletterSpacing_mobile": "",
      "descriptiontypographyBold": "",
      "descriptiontypographyItalic": "",
      "descriptiontypographyUnderline": "",
      "descriptionalign": "",
      "descriptiontypographyLetterCase": "",
      "pricefont": "",
      "pricefontVariant": "",
      "pricefontSize": "",
      "pricefontSize_mobile": "",
      "pricelineHeight": "",
      "pricelineHeight_mobile": "",
      "priceletterSpacing": "",
      "priceletterSpacing_mobile": "",
      "pricetypographyBold": "",
      "pricetypographyItalic": "",
      "pricetypographyUnderline": "",
      "pricealign": "",
      "pricetypographyLetterCase": "",
      "priceColor": "",
      "saleColor":"",
      "buttonStyle": "flat",
      "buttonBgColor": "",
      "buttonShadow": "",
      "buttonLineHeight": "",
      "buttonfont": "",
      "buttonfontVariant": "",
      "buttonfontSize": "",
      "buttonfontSize_mobile": "",
      "buttonlineHeight": "",
      "buttonlineHeight_mobile": "",
      "buttonletterSpacing": "",
      "buttonletterSpacing_mobile": "",
      "buttontypographyBold": "",
      "buttontypographyItalic": "",
      "buttontypographyUnderline": "",
      "buttonalign": "",
      "buttontypographyLetterCase": "",
      "buttonSize":"4",
      "buttonPaddingTop": "16",
      "buttonPaddingLeft": "20",
      "buttonBorderRadius": "",
      "imageShadow": "",
      "imageBorderRadius": "3",
      "imageBorderStyle": "solid",
      "imageBorderColor": "#ccc",
      "imageBorderTop": "1",
      "imageBorderBottom": "1",
      "imageBorderLeft": "1",
      "imageBorderRight": "1",
      "imageBorderSync": true,
      "imagePadding": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "wcfeaturedproductsgrid":{
      "columns": "4",
      "pagination": false,
      "limit": "-1",
      "showItemsCount": false,
      "showOrderBy": false,
      "selectProductIds": false,
      "productIds": [],
      "selectProductSkus": false,
      "productSkus": [],
      "selectCategories": false,
      "productCategories": [],
      "queryCategoriesOperator": "IN",
      "selectTags": false,
      "productTags": [],
      "queryTagsOperator": "IN",
      "selectGroup": false,
      "productGroups": "",
      "selectByVisibility": false,
      "productVisibility": "",
      "queryByAttribute": false,
      "queryAttribute": "",
      "queryAttributeTerms": [],
      "queryTermsOperator": "IN",
      "querySource": "featured_products",
      "queryInclude": "",
      "queryIncludeBy": "",
      "queryIncludeTerm": "",
      "queryExclude": "",
      "queryExcludeBy": "",
      "queryExcludeTerm": "",
      "queryOrderBy": [],
      "queryOrder": "ASC",
      "align": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "descriptionfont": "",
      "descriptionfontVariant": "",
      "descriptionfontSize": "",
      "descriptionfontSize_mobile": "",
      "descriptionlineHeight": "",
      "descriptionlineHeight_mobile": "",
      "descriptionletterSpacing": "",
      "descriptionletterSpacing_mobile": "",
      "descriptiontypographyBold": "",
      "descriptiontypographyItalic": "",
      "descriptiontypographyUnderline": "",
      "descriptionalign": "",
      "descriptiontypographyLetterCase": "",
      "pricefont": "",
      "pricefontVariant": "",
      "pricefontSize": "",
      "pricefontSize_mobile": "",
      "pricelineHeight": "",
      "pricelineHeight_mobile": "",
      "priceletterSpacing": "",
      "priceletterSpacing_mobile": "",
      "pricetypographyBold": "",
      "pricetypographyItalic": "",
      "pricetypographyUnderline": "",
      "pricealign": "",
      "pricetypographyLetterCase": "",
      "priceColor": "",
      "buttonStyle": "flat",
      "buttonBgColor": "",
      "buttonShadow": "",
      "buttonLineHeight": "",
      "buttonfont": "",
      "buttonfontVariant": "",
      "buttonfontSize": "",
      "buttonfontSize_mobile": "",
      "buttonlineHeight": "",
      "buttonlineHeight_mobile": "",
      "buttonletterSpacing": "",
      "buttonletterSpacing_mobile": "",
      "buttontypographyBold": "",
      "buttontypographyItalic": "",
      "buttontypographyUnderline": "",
      "buttonalign": "",
      "buttontypographyLetterCase": "",
      "buttonSize":"4",
      "buttonPaddingTop": "16",
      "buttonPaddingLeft": "20",
      "buttonBorderRadius": "",
      "imageShadow": "",
      "imageBorderRadius": "",
      "imageBorderStyle": "",
      "imageBorderColor": "",
      "imageBorderTop": "1",
      "imageBorderBottom": "1",
      "imageBorderLeft": "1",
      "imageBorderRight": "1",
      "imageBorderSync": true,
      "imagePadding": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "wcsaleproductsgrid":{
      "columns": "4",
      "pagination": false,
      "limit": "-1",
      "showItemsCount": false,
      "showOrderBy": false,
      "selectProductIds": false,
      "productIds": [],
      "selectProductSkus": false,
      "productSkus": [],
      "selectCategories": false,
      "productCategories": [],
      "queryCategoriesOperator": "IN",
      "selectTags": false,
      "productTags": [],
      "queryTagsOperator": "IN",
      "selectGroup": false,
      "productGroups": "",
      "selectByVisibility": false,
      "productVisibility": "",
      "queryByAttribute": false,
      "queryAttribute": "",
      "queryAttributeTerms": [],
      "queryTermsOperator": "IN",
      "querySource": "sale_products",
      "queryInclude": "",
      "queryIncludeBy": "",
      "queryIncludeTerm": "",
      "queryExclude": "",
      "queryExcludeBy": "",
      "queryExcludeTerm": "",
      "queryOrderBy": [],
      "queryOrder": "ASC",
      "align": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "descriptionfont": "",
      "descriptionfontVariant": "",
      "descriptionfontSize": "",
      "descriptionfontSize_mobile": "",
      "descriptionlineHeight": "",
      "descriptionlineHeight_mobile": "",
      "descriptionletterSpacing": "",
      "descriptionletterSpacing_mobile": "",
      "descriptiontypographyBold": "",
      "descriptiontypographyItalic": "",
      "descriptiontypographyUnderline": "",
      "descriptionalign": "",
      "descriptiontypographyLetterCase": "",
      "pricefont": "",
      "pricefontVariant": "",
      "pricefontSize": "",
      "pricefontSize_mobile": "",
      "pricelineHeight": "",
      "pricelineHeight_mobile": "",
      "priceletterSpacing": "",
      "priceletterSpacing_mobile": "",
      "pricetypographyBold": "",
      "pricetypographyItalic": "",
      "pricetypographyUnderline": "",
      "pricealign": "",
      "pricetypographyLetterCase": "",
      "priceColor": "",
      "buttonStyle": "flat",
      "buttonBgColor": "",
      "buttonShadow": "",
      "buttonLineHeight": "",
      "buttonfont": "",
      "buttonfontVariant": "",
      "buttonfontSize": "",
      "buttonfontSize_mobile": "",
      "buttonlineHeight": "",
      "buttonlineHeight_mobile": "",
      "buttonletterSpacing": "",
      "buttonletterSpacing_mobile": "",
      "buttontypographyBold": "",
      "buttontypographyItalic": "",
      "buttontypographyUnderline": "",
      "buttonalign": "",
      "buttontypographyLetterCase": "",
      "buttonSize":"4",
      "buttonPaddingTop": "16",
      "buttonPaddingLeft": "20",
      "buttonBorderRadius": "",
      "imageShadow": "",
      "imageBorderRadius": "",
      "imageBorderStyle": "",
      "imageBorderColor": "",
      "imageBorderTop": "1",
      "imageBorderBottom": "1",
      "imageBorderLeft": "1",
      "imageBorderRight": "1",
      "imageBorderSync": true,
      "imagePadding": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "wcbestsellingproductsgrid":{
      "columns": "4",
      "pagination": false,
      "limit": "-1",
      "showItemsCount": false,
      "showOrderBy": false,
      "selectProductIds": false,
      "productIds": [],
      "selectProductSkus": false,
      "productSkus": [],
      "selectCategories": false,
      "productCategories": [],
      "queryCategoriesOperator": "IN",
      "selectTags": false,
      "productTags": [],
      "queryTagsOperator": "IN",
      "selectGroup": false,
      "productGroups": "",
      "selectByVisibility": false,
      "productVisibility": "",
      "queryByAttribute": false,
      "queryAttribute": "",
      "queryAttributeTerms": [],
      "queryTermsOperator": "IN",
      "querySource": "best_selling_products",
      "queryInclude": "",
      "queryIncludeBy": "",
      "queryIncludeTerm": "",
      "queryExclude": "",
      "queryExcludeBy": "",
      "queryExcludeTerm": "",
      "queryOrderBy": [],
      "queryOrder": "ASC",
      "align": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "descriptionfont": "",
      "descriptionfontVariant": "",
      "descriptionfontSize": "",
      "descriptionfontSize_mobile": "",
      "descriptionlineHeight": "",
      "descriptionlineHeight_mobile": "",
      "descriptionletterSpacing": "",
      "descriptionletterSpacing_mobile": "",
      "descriptiontypographyBold": "",
      "descriptiontypographyItalic": "",
      "descriptiontypographyUnderline": "",
      "descriptionalign": "",
      "descriptiontypographyLetterCase": "",
      "pricefont": "",
      "pricefontVariant": "",
      "pricefontSize": "",
      "pricefontSize_mobile": "",
      "pricelineHeight": "",
      "pricelineHeight_mobile": "",
      "priceletterSpacing": "",
      "priceletterSpacing_mobile": "",
      "pricetypographyBold": "",
      "pricetypographyItalic": "",
      "pricetypographyUnderline": "",
      "pricealign": "",
      "pricetypographyLetterCase": "",
      "priceColor": "",
      "buttonStyle": "flat",
      "buttonBgColor": "",
      "buttonShadow": "",
      "buttonLineHeight": "",
      "buttonfont": "",
      "buttonfontVariant": "",
      "buttonfontSize": "",
      "buttonfontSize_mobile": "",
      "buttonlineHeight": "",
      "buttonlineHeight_mobile": "",
      "buttonletterSpacing": "",
      "buttonletterSpacing_mobile": "",
      "buttontypographyBold": "",
      "buttontypographyItalic": "",
      "buttontypographyUnderline": "",
      "buttonalign": "",
      "buttontypographyLetterCase": "",
      "buttonSize":"4",
      "buttonPaddingTop": "16",
      "buttonPaddingLeft": "20",
      "buttonBorderRadius": "",
      "imageShadow": "",
      "imageBorderRadius": "",
      "imageBorderStyle": "",
      "imageBorderColor": "",
      "imageBorderTop": "1",
      "imageBorderBottom": "1",
      "imageBorderLeft": "1",
      "imageBorderRight": "1",
      "imageBorderSync": true,
      "imagePadding": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "wcrecentproductsgrid":{
      "columns": "4",
      "pagination": false,
      "limit": "-1",
      "showItemsCount": false,
      "showOrderBy": false,
      "selectProductIds": false,
      "productIds": [],
      "selectProductSkus": false,
      "productSkus": [],
      "selectCategories": false,
      "productCategories": [],
      "queryCategoriesOperator": "IN",
      "selectTags": false,
      "productTags": [],
      "queryTagsOperator": "IN",
      "selectGroup": false,
      "productGroups": "",
      "selectByVisibility": false,
      "productVisibility": "",
      "queryByAttribute": false,
      "queryAttribute": "",
      "queryAttributeTerms": [],
      "queryTermsOperator": "IN",
      "querySource": "recent_products",
      "queryInclude": "",
      "queryIncludeBy": "",
      "queryIncludeTerm": "",
      "queryExclude": "",
      "queryExcludeBy": "",
      "queryExcludeTerm": "",
      "queryOrderBy": [],
      "queryOrder": "ASC",
      "align": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "descriptionfont": "",
      "descriptionfontVariant": "",
      "descriptionfontSize": "",
      "descriptionfontSize_mobile": "",
      "descriptionlineHeight": "",
      "descriptionlineHeight_mobile": "",
      "descriptionletterSpacing": "",
      "descriptionletterSpacing_mobile": "",
      "descriptiontypographyBold": "",
      "descriptiontypographyItalic": "",
      "descriptiontypographyUnderline": "",
      "descriptionalign": "",
      "descriptiontypographyLetterCase": "",
      "pricefont": "",
      "pricefontVariant": "",
      "pricefontSize": "",
      "pricefontSize_mobile": "",
      "pricelineHeight": "",
      "pricelineHeight_mobile": "",
      "priceletterSpacing": "",
      "priceletterSpacing_mobile": "",
      "pricetypographyBold": "",
      "pricetypographyItalic": "",
      "pricetypographyUnderline": "",
      "pricealign": "",
      "pricetypographyLetterCase": "",
      "priceColor": "",
      "buttonStyle": "flat",
      "buttonBgColor": "",
      "buttonShadow": "",
      "buttonLineHeight": "",
      "buttonfont": "",
      "buttonfontVariant": "",
      "buttonfontSize": "",
      "buttonfontSize_mobile": "",
      "buttonlineHeight": "",
      "buttonlineHeight_mobile": "",
      "buttonletterSpacing": "",
      "buttonletterSpacing_mobile": "",
      "buttontypographyBold": "",
      "buttontypographyItalic": "",
      "buttontypographyUnderline": "",
      "buttonalign": "",
      "buttontypographyLetterCase": "",
      "buttonSize":"4",
      "buttonPaddingTop": "16",
      "buttonPaddingLeft": "20",
      "buttonBorderRadius": "",
      "imageShadow": "",
      "imageBorderRadius": "",
      "imageBorderStyle": "",
      "imageBorderColor": "",
      "imageBorderTop": "1",
      "imageBorderBottom": "1",
      "imageBorderLeft": "1",
      "imageBorderRight": "1",
      "imageBorderSync": true,
      "imagePadding": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "wctopratedproductsgrid":{
      "columns": "4",
      "pagination": false,
      "limit": "-1",
      "showItemsCount": false,
      "showOrderBy": false,
      "selectProductIds": false,
      "productIds": [],
      "selectProductSkus": false,
      "productSkus": [],
      "selectCategories": false,
      "productCategories": [],
      "queryCategoriesOperator": "IN",
      "selectTags": false,
      "productTags": [],
      "queryTagsOperator": "IN",
      "selectGroup": false,
      "productGroups": "",
      "selectByVisibility": false,
      "productVisibility": "",
      "queryByAttribute": false,
      "queryAttribute": "",
      "queryAttributeTerms": [],
      "queryTermsOperator": "IN",
      "querySource": "top_rated_products",
      "queryInclude": "",
      "queryIncludeBy": "",
      "queryIncludeTerm": "",
      "queryExclude": "",
      "queryExcludeBy": "",
      "queryExcludeTerm": "",
      "queryOrderBy": [],
      "queryOrder": "ASC",
      "align": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "descriptionfont": "",
      "descriptionfontVariant": "",
      "descriptionfontSize": "",
      "descriptionfontSize_mobile": "",
      "descriptionlineHeight": "",
      "descriptionlineHeight_mobile": "",
      "descriptionletterSpacing": "",
      "descriptionletterSpacing_mobile": "",
      "descriptiontypographyBold": "",
      "descriptiontypographyItalic": "",
      "descriptiontypographyUnderline": "",
      "descriptionalign": "",
      "descriptiontypographyLetterCase": "",
      "pricefont": "",
      "pricefontVariant": "",
      "pricefontSize": "",
      "pricefontSize_mobile": "",
      "pricelineHeight": "",
      "pricelineHeight_mobile": "",
      "priceletterSpacing": "",
      "priceletterSpacing_mobile": "",
      "pricetypographyBold": "",
      "pricetypographyItalic": "",
      "pricetypographyUnderline": "",
      "pricealign": "",
      "pricetypographyLetterCase": "",
      "priceColor": "",
      "buttonStyle": "flat",
      "buttonBgColor": "",
      "buttonShadow": "",
      "buttonLineHeight": "",
      "buttonfont": "",
      "buttonfontVariant": "",
      "buttonfontSize": "",
      "buttonfontSize_mobile": "",
      "buttonlineHeight": "",
      "buttonlineHeight_mobile": "",
      "buttonletterSpacing": "",
      "buttonletterSpacing_mobile": "",
      "buttontypographyBold": "",
      "buttontypographyItalic": "",
      "buttontypographyUnderline": "",
      "buttonalign": "",
      "buttontypographyLetterCase": "",
      "buttonSize":"4",
      "buttonPaddingTop": "16",
      "buttonPaddingLeft": "20",
      "buttonBorderRadius": "",
      "imageShadow": "",
      "imageBorderRadius": "",
      "imageBorderStyle": "",
      "imageBorderColor": "",
      "imageBorderTop": "1",
      "imageBorderBottom": "1",
      "imageBorderLeft": "1",
      "imageBorderRight": "1",
      "imageBorderSync": true,
      "imagePadding": ""
    },
    "wpwidgetblock":{
      "hideOnDesktop": false,
      "hideOnMobile": false,
      "widgetdataoptions": "",
      "widgetresult": "",
      "widgetdata": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "columns": "4",
      "titleColor":"",
      "titleBottomMargin":"16",
      "contentColor":"",
      "fontSize": "",
      "fontSize_mobile": "",
      "contentalign": "",
      "contentfont": "",
      "contentfontVariant": "",
      "contentfontSize": "",
      "contentfontSize_mobile": "",
      "contentlineHeight": "",
      "contentlineHeight_mobile": "",
      "contentletterSpacing": "",
      "contentletterSpacing_mobile": "",
      "contenttypographyBold": "",
      "contenttypographyItalic": "",
      "contenttypographyUnderline": "",
      "contenttypographyLetterCase": ""
    },
    "posts":{
      "columns": "1",
      "pagination": false,
      "queryType": "custom",
      "queryByPostType": true,
      "queryPostType": [],
      "queryByCategory": false,
      "queryCategory": [],
      "queryByTags": false,
      "queryTags": [],
      "queryByAuthors": false,
      "queryAuthors": [],
      "queryOrderBy": [],
      "queryOrder": "ASC",
      "manualQuery": "post_type=post&posts_per_page=3&order=desc&post_status=publish",
      "numberPerPages": 10,
      "showFeaturedImage": false,
      "showTitle": true,
      "titleHtmlTag": "h4",
      "showMetaOptions": false,
      "showDateModifiedMeta": true,
      "showAuthorMeta": true,
      "showDateMeta": true,
      "showTimeMeta": true,
      "showCommentCountMeta": true,
      "metaSeparator": ",",
      "showExcerpt": true,
      "excerptLength": 20,
      "showReadMore": true,
      "readMoreText": "Continue Reading →",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "blockBorderRadius": "",
      "blockBorderTop": "",
      "blockBorderBottom": "",
      "blockBorderLeft": "",
      "blockBorderRight": "",
      "blockBorderSync": true,
      "blockBorderStyle":"solid",
      "blockBorderColor": "",
      "imageShadow": "",
      "imageBorderRadiusSync": true,
      "imageBorderRadiusTopRight": "",
      "imageBorderRadiusTopLeft": "",
      "imageBorderRadiusBottomRight": "",
      "imageBorderRadiusBottomLeft": "",
      "imageBorderStyle": "solid",
      "imageBorderColor": "",
      "imageBorderTop": "",
      "imageBorderBottom": "",
      "imageBorderLeft": "",
      "imageBorderRight": "",
      "imageBorderSync": true,
      "imagePadding": "",
      "titlealign": "left",
      "titlefont": "",
      "titlefontVariant": "",
      "titlefontSize": "",
      "titlefontSize_mobile": "",
      "titlelineHeight": "",
      "titlelineHeight_mobile": "",
      "titleletterSpacing": "",
      "titleletterSpacing_mobile": "",
      "titletypographyBold": true,
      "titletypographyItalic": "",
      "titletypographyUnderline": "",
      "titletypographyLetterCase": "",
      "titleTextColor": "",
      "metatextalign": "left",
      "metatextfont": "",
      "metatextfontVariant": "",
      "metatextfontSize": "",
      "metatextfontSize_mobile": "",
      "metatextlineHeight": "",
      "metatextlineHeight_mobile": "",
      "metatextletterSpacing": "",
      "metatextletterSpacing_mobile": "",
      "metatexttypographyBold": "",
      "metatexttypographyItalic": "",
      "metatexttypographyUnderline": "",
      "metatexttypographyLetterCase": "",
      "metatextTextColor": "",
      "excerptalign": "left",
      "excerptfont": "",
      "excerptfontVariant": "",
      "excerptfontSize": "",
      "excerptfontSize_mobile": "",
      "excerptlineHeight": "",
      "excerptlineHeight_mobile": "",
      "excerptletterSpacing": "",
      "excerptletterSpacing_mobile": "",
      "excerpttypographyBold": "",
      "excerpttypographyItalic": "",
      "excerpttypographyUnderline": "",
      "excerpttypographyLetterCase": "",
      "excerptTextColor": "",
      "readmoretextalign": "left",
      "readmoretextfont": "",
      "readmoretextfontVariant": "",
      "readmoretextfontSize": "",
      "readmoretextfontSize_mobile": "",
      "readmoretextlineHeight": "",
      "readmoretextlineHeight_mobile": "",
      "readmoretextletterSpacing": "",
      "readmoretextletterSpacing_mobile": "",
      "readmoretexttypographyBold": "",
      "readmoretexttypographyItalic": "",
      "readmoretexttypographyUnderline": "",
      "readmoretexttypographyLetterCase": "",
      "readmoreTextColor": "",
      "paginationalign": "left",
      "paginationfont": "",
      "paginationfontVariant": "",
      "paginationfontSize": "",
      "paginationfontSize_mobile": "",
      "paginationlineHeight": "",
      "paginationlineHeight_mobile": "",
      "paginationletterSpacing": "",
      "paginationletterSpacing_mobile": "",
      "paginationtypographyBold": "",
      "paginationtypographyItalic": "",
      "paginationtypographyUnderline": "",
      "paginationtypographyLetterCase": "",
      "paginationTextColor": "",
      "hideOnDesktop": false,
      "hideOnMobile": false,
      "postpaddingTop": "",
      "postpaddingBottom": "",
      "postpaddingLeft": "",
      "postpaddingRight": "",
      "postpaddingSync": true,
      "postBackgroundColor": "",
      "spaceBottom": "",
      "postshadow": "",
      "postshadowColor":"",
      "postshadowHorizontal":0,
      "postshadowVertical":0,
      "postshadowBlur":3,
      "postshadowSpread":0,
      "postshadowPosition":"outline",
      "imageMarginTop": "",
      "imageMarginBottom": "",
      "imageMarginLeft": "",
      "imageMarginRight": "",
      "imageMarginSync": true
    }
    ,
    "posttitle":{
      "headerTxt": "[seedprod tag=\"the_title\"]",
      "tag": "h1",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "center",
      "typographyLetterCase": ""
    },
    "archivetitle":{
      "headerTxt": "[seedprod tag=\"the_archive_title\"]",
      "tag": "h1",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "center",
      "typographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "postcontent":{
      "editortxt":"code",
      "txt": "[seedprod tag=\"the_content\"]",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "typographyLetterCase": ""
    },
    "postexcerpt":{
      "txt": "[seedprod tag=\"the_excerpt\"]",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "typographyLetterCase": ""
    },
    "postfeaturedimage":{
      "link": "",
      "openNewWindow": false,
      "noFollow": false,
      "unit":"px",
      "src": "",
      "altTxt": "",
      "link": "",
      "width": "",
      "height": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "imagePadding": "",
      "align": "center",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "imageBorderRadius": "",
      "imageBorderTop": "0",
      "imageBorderBottom": "0",
      "imageBorderLeft": "0",
      "imageBorderRight": "0",
      "imageBorderSync": true,
      "imageBorderStyle":"solid",
      "imageBorderColor": "",
      "blockTemplateId":false,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "postauthorbox":{
      "bgStyle": "s",
      "bgGradient":{ "type": "linear","position": "center", "angle": 0,"color1":"","color1location":0,"color2":"","color2location":100 },
      "bgColor":"",
      "bgImage":"",
      "bgPosition":"",
      "profilePictureToggle": true,
      "displayNameToggle": true,
      "biographyToggle": true,
      "htmlTag": "div",
      "link": "none",
      "namefont": "",
      "namefontVariant": "",
      "namefontSize": "",
      "namefontSize_mobile": "",
      "namelineHeight": "",
      "namelineHeight_mobile": "",
      "nameletterSpacing": "",
      "nameletterSpacing_mobile": "",
      "nametypographyBold": "",
      "nametypographyItalic": "",
      "nametypographyUnderline": "",
      "namealign": "",
      "nametypographyLetterCase": "",
      "nameColor": "",
      "biographyfont": "",
      "biographyfontVariant": "",
      "biographyfontSize": "",
      "biographyfontSize_mobile": "",
      "biographylineHeight": "",
      "biographylineHeight_mobile": "",
      "biographyletterSpacing": "",
      "biographyletterSpacing_mobile": "",
      "biographytypographyBold": "",
      "biographytypographyItalic": "",
      "biographytypographyUnderline": "",
      "biographyalign": "",
      "biographytypographyLetterCase": "",
      "biographyColor": "",
      "backgroundColor": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadiusTL": "",
      "borderRadiusTR": "",
      "borderRadiusBL": "",
      "borderRadiusBR": "",
      "borderRadiusSync":true,
      "borderTop": "0",
      "borderBottom": "0",
      "borderLeft": "0",
      "borderRight": "0",
      "borderSync": true,
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "borderStyle":"solid",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "postcomments": {
      "bgStyle": "s",
      "bgGradient":{ "type": "linear","position": "center", "angle": 0,"color1":"","color1location":0,"color2":"","color2location":100 },
      "bgColor":"",
      "bgImage":"",
      "bgPosition":"",
      "align": "",
      "contentPolicy": "",
      "txt": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadiusTL": "",
      "borderRadiusTR": "",
      "borderRadiusBL": "",
      "borderRadiusBR": "",
      "borderRadiusSync":true,
      "borderTop": "0",
      "borderBottom": "0",
      "borderLeft": "0",
      "borderRight": "0",
      "borderSync": true,
      "borderStyle":"solid",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "postnavigation":{
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "center",
      "typographyLetterCase": "",
      "navigationColor": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "postinfo": {
      "items": [{ "type": "author", "avatar": true, "avatarSize": "24", "date_format": "default", "custom_date_format": "F j, Y", "time_format": "default", "custom_time_format": "g:i a", "terms_taxonomy" : "", "iconType": "default", "icon": "" }, { "type": "date", "avatar": false, "avatarSize": "20", "date_format": "default", "custom_date_format": "F j, Y", "time_format": "default", "custom_time_format": "g:i a", "terms_taxonomy" : "", "iconType": "default", "icon": "" }, { "type": "time", "avatar": false, "avatarSize": "20", "date_format": "default", "custom_date_format": "F j, Y", "time_format": "default", "custom_time_format": "g:i a", "terms_taxonomy" : "", "iconType": "default", "icon": "" }, { "type": "comments", "avatar": false, "avatarSize": "20", "date_format": "default", "custom_date_format": "F j, Y", "time_format": "default", "custom_time_format": "g:i a", "terms_taxonomy" : "", "iconType": "default", "icon": "" }],
      "spaceBetween": "",
      "alignment":"left",
      "divider": ",",
      "textColor": "",
      "textfont": "",
      "textfontVariant": "",
      "textfontSize": "",
      "textfontSize_mobile": "",
      "textlineHeight": "",
      "textlineHeight_mobile": "",
      "textletterSpacing": "",
      "textletterSpacing_mobile": "",
      "texttypographyBold": "",
      "texttypographyItalic": "",
      "texttypographyUnderline": "",
      "texttypographyLetterCase": "",
      "iconColor": "",
      "bgStyle": "s",
      "bgGradient":{ "type": "linear","position": "center", "angle": 0,"color1":"","color1location":0,"color2":"","color2location":100 },
      "bgColor":"",
      "bgImage":"",
      "bgPosition":"",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadiusTL": "",
      "borderRadiusTR": "",
      "borderRadiusBL": "",
      "borderRadiusBR": "",
      "borderRadiusSync":true,
      "borderTop": "0",
      "borderBottom": "0",
      "borderLeft": "0",
      "borderRight": "0",
      "borderSync": true,
      "borderStyle":"solid",
      "showIcons": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "menucart": {
      "customClass":"",
      "hideOnEmpty": false,
      "showSubtotal": true,
      "align":"left",
      "badgeColor": "#df2a4a",
      "badgeTextColor": "#ffffff",
      "textColor": "",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "typographyLetterCase": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "producttitle":{
      "headerTxt": "[seedprod_wc tag=\"the_title\"]",
      "tag": "h1",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "borderRadius": "",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "textShadow": "",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "",
      "typographyLetterCase": ""
    },
    "productfeaturedimage":{
      "link": "",
      "openNewWindow": false,
      "noFollow": false,
      "unit":"px",
      "src": "",
      "altTxt": "",
      "link": "",
      "width": "",
      "height": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "imagePadding": "",
      "align": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "imageBorderRadius": "",
      "imageBorderTop": "0",
      "imageBorderBottom": "0",
      "imageBorderLeft": "0",
      "imageBorderRight": "0",
      "imageBorderSync": true,
      "imageBorderStyle":"solid",
      "imageBorderColor": "",
      "blockTemplateId":false,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "productprice":{
      "align": "left",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "typographyLetterCase": "",
      "textColor": "",
      "saleTextColor": "",
      "salefont": "",
      "salefontVariant": "",
      "salefontSize": "",
      "salefontSize_mobile": "",
      "salelineHeight": "",
      "salelineHeight_mobile": "",
      "saleletterSpacing": "",
      "saleletterSpacing_mobile": "",
      "saletypographyBold": "",
      "saletypographyItalic": "",
      "saletypographyUnderline": "",
      "saletypographyLetterCase": "",
      "stacked": false,
      "spaceBetween": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "customClass":"",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "addtocart":{
      "action": "link",
      "btnTxt": "Add To Cart",
      "btnStyle": "",
      "textColor": "",
      "bgColor": "",
      "buttonTextColor":"",
      "bgColorHover":"",
      "buttonTextHoverColor":"",
      "buttonNormalStyle":"s",
      "buttonNormalBGtype":"radial",
      "buttonNormalBGposition":"",
      "buttonHoverStyle":"s",
      "buttonHoverBGtype":"radial",
      "buttonHoverBGposition":"",
      "btnStyleHover":"",
      "btnPaddingTop": "8",
      "btnPaddingLeft": "12",
      "btnSize":"2",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "4",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "15",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "",
      "typographyLetterCase": "",
      "quantityfont": "",
      "quantityfontVariant": "",
      "quantityfontSize": "22",
      "quantityfontSize_mobile": "",
      "quantitylineHeight": "",
      "quantitylineHeight_mobile": "",
      "quantityletterSpacing": "",
      "quantityletterSpacing_mobile": "",
      "quantitytypographyBold": "",
      "quantitytypographyItalic": "",
      "quantitytypographyUnderline": "",
      "quantityalign": "",
      "quantitytypographyLetterCase": "",
      "spaceBetween": "10",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "productmeta":{
      "metaView": "inline",
      "spaceBetween": "",
      "alignment":"left",
      "divider": ",",
      "textColor": "",
      "textfont": "",
      "textfontVariant": "",
      "textfontSize": "",
      "textfontSize_mobile": "",
      "textlineHeight": "",
      "textlineHeight_mobile": "",
      "textletterSpacing": "",
      "textletterSpacing_mobile": "",
      "texttypographyBold": "",
      "texttypographyItalic": "",
      "texttypographyUnderline": "",
      "texttypographyLetterCase": "",
      "linkColor": "",
      "linkfont": "",
      "linkfontVariant": "",
      "linkfontSize": "",
      "linkfontSize_mobile": "",
      "linklineHeight": "",
      "linklineHeight_mobile": "",
      "linkletterSpacing": "",
      "linkletterSpacing_mobile": "",
      "linktypographyBold": "",
      "linktypographyItalic": "",
      "linktypographyUnderline": "",
      "linktypographyLetterCase": "",
      "dividerColor": "",
      "dividerfont": "",
      "dividerfontVariant": "",
      "dividerfontSize": "",
      "dividerfontSize_mobile": "",
      "dividerlineHeight": "",
      "dividerlineHeight_mobile": "",
      "dividerletterSpacing": "",
      "dividerletterSpacing_mobile": "",
      "dividertypographyBold": "",
      "dividertypographyItalic": "",
      "dividertypographyUnderline": "",
      "dividertypographyLetterCase": "",
      "bgStyle": "s",
      "bgGradient":{ "type": "linear","position": "center", "angle": 0,"color1":"","color1location":0,"color2":"","color2location":100 },
      "bgColor":"",
      "bgImage":"",
      "bgPosition":"",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadiusTL": "",
      "borderRadiusTR": "",
      "borderRadiusBL": "",
      "borderRadiusBR": "",
      "borderRadiusSync":true,
      "borderTop": "0",
      "borderBottom": "0",
      "borderLeft": "0",
      "borderRight": "0",
      "borderSync": true,
      "borderStyle":"solid",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "productcontent":{
      "editortxt":"code",
      "txt": "[seedprod_wc tag=\"the_content\"]",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "borderRadius": "",
      "borderRadiusTL":"",
      "borderRadiusTR":"",
      "borderRadiusBL":"",
      "borderRadiusBR":"",
      "borderRadiusSync":true,
      "borderTop":"0",
      "borderBottom":"0",
      "borderLeft":"0",
      "borderRight":"0",
      "borderSync":true,
      "borderStyle":"solid",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "typographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "shortdescription":{
      "editortxt":"code",
      "txt": "[seedprod_wc tag=\"short_description\"]",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "borderRadius": "",
      "borderRadiusTL":"",
      "borderRadiusTR":"",
      "borderRadiusBL":"",
      "borderRadiusBR":"",
      "borderRadiusSync":true,
      "borderTop":"0",
      "borderBottom":"0",
      "borderLeft":"0",
      "borderRight":"0",
      "borderSync":true,
      "borderStyle":"solid",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "typographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "productdatatabs":{
      "txt":"[sp_product_data_tabs]",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "borderRadius": "",
      "borderRadiusTL":"",
      "borderRadiusTR":"",
      "borderRadiusBL":"",
      "borderRadiusBR":"",
      "borderRadiusSync":true,
      "borderTop":"0",
      "borderBottom":"0",
      "borderLeft":"0",
      "borderRight":"0",
      "borderSync":true,
      "borderStyle":"solid",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "hideOnDesktop": false,
      "hideOnMobile": false,
      "showNormalSettings": false,
      "showActiveSettings": false,
      "tabsNormalTextColor": "",
      "tabsActiveTextColor": "",
      "tabsNormalBackgroundColor": "",
      "tabsActiveBackgroundColor": "",
      "tabsNormalBorderColor": "",
      "tabsActiveBorderColor": "",
      "tabalign": "left",
      "tabfont": "",
      "tabfontVariant": "",
      "tabfontSize": "",
      "tabfontSize_mobile": "",
      "tablineHeight": "",
      "tablineHeight_mobile": "",
      "tabletterSpacing": "",
      "tabletterSpacing_mobile": "",
      "tabtypographyBold": "",
      "tabtypographyItalic": "",
      "tabtypographyUnderline": "",
      "tabtypographyLetterCase": "",
      "tabsBorderRadius": "",
      "panelTextColor": "",
      "panelfont": "",
      "panelfontVariant": "",
      "panelfontSize": "",
      "panelfontSize_mobile": "",
      "panellineHeight": "",
      "panellineHeight_mobile": "",
      "panelletterSpacing": "",
      "panelletterSpacing_mobile": "",
      "paneltypographyBold": "",
      "paneltypographyItalic": "",
      "paneltypographyUnderline": "",
      "paneltypographyLetterCase": "",
      "panelHeadingTextColor": "",
      "panelheadingfont": "",
      "panelheadingfontVariant": "",
      "panelheadingfontSize": "",
      "panelheadingfontSize_mobile": "",
      "panelheadinglineHeight": "",
      "panelheadinglineHeight_mobile": "",
      "panelheadingletterSpacing": "",
      "panelheadingletterSpacing_mobile": "",
      "panelheadingtypographyBold": "",
      "panelheadingtypographyItalic": "",
      "panelheadingtypographyUnderline": "",
      "panelheadingtypographyLetterCase": "",
      "panelborderRadius": "",
      "panelborderRadiusTL": "",
      "panelborderRadiusTR": "",
      "panelborderRadiusBL": "",
      "panelborderRadiusBR": "",
      "panelborderRadiusSync":true,
      "panelborderTop": "",
      "panelborderBottom": "",
      "panelborderLeft": "",
      "panelborderRight": "",
      "panelborderSync": true,
      "panelborderStyle":"solid",
      "panelborder": "",
      "panelborderStyle": "",
      "panelborderSize": "",
      "panelborderColor": "",
      "panelshadow": "",
      "panelshadowColor":"",
      "panelshadowHorizontal":0,
      "panelshadowVertical":0,
      "panelshadowBlur":3,
      "panelshadowSpread":0,
      "panelshadowPosition":"outline",
      "panelpaddingTop": "",
      "panelpaddingBottom": "",
      "panelpaddingLeft": "",
      "panelpaddingRight": "",
      "panelpaddingSync": true
    },
    "additionalinformation":{
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "headeralign": "",
      "headerfont": "",
      "headerfontVariant": "",
      "headerfontSize": "",
      "headerfontSize_mobile": "",
      "headerlineHeight": "",
      "headerlineHeight_mobile": "",
      "headerletterSpacing": "",
      "headerletterSpacing_mobile": "",
      "headertypographyBold": "",
      "headertypographyItalic": "",
      "headertypographyUnderline": "",
      "headertypographyLetterCase": "",
      "headerTextColor": "",
      "font":"",
      "fontVariant":"",
      "fontSize":"",
      "fontSize_mobile":"",
      "lineHeight":"",
      "lineHeight_mobile":"",
      "letterSpacing":"",
      "letterSpacing_mobile":"",
      "typographyBold":"",
      "typographyItalic":"",
      "typographyUnderline":"",
      "align":"left",
      "typographyLetterCase":"",
      "textColor":"",
      "customClass": "",
      "hideOnDesktop": false,
      "hideOnMobile": false,
      "showHeader": true
    },
    "productrelated":{
      "columns": "1",
      "pagination": false,
      "limit": "1",
      "showItemsCount": false,
      "showOrderBy": false,
      "selectProductIds": false,
      "productIds": [],
      "selectProductSkus": false,
      "productSkus": [],
      "selectCategories": false,
      "productCategories": [],
      "queryCategoriesOperator": "IN",
      "selectTags": false,
      "productTags": [],
      "queryTagsOperator": "IN",
      "selectGroup": false,
      "productGroups": "",
      "selectByVisibility": false,
      "productVisibility": "",
      "queryByAttribute": false,
      "queryAttribute": "",
      "queryAttributeTerms": [],
      "queryTermsOperator": "IN",
      "querySource": "product_related",
      "queryInclude": "",
      "queryIncludeBy": "",
      "queryIncludeTerm": "",
      "queryExclude": "",
      "queryExcludeBy": "",
      "queryExcludeTerm": "",
      "queryOrderBy": [],
      "queryOrder": "ASC",
      "align": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "descriptionfont": "",
      "descriptionfontVariant": "",
      "descriptionfontSize": "",
      "descriptionfontSize_mobile": "",
      "descriptionlineHeight": "",
      "descriptionlineHeight_mobile": "",
      "descriptionletterSpacing": "",
      "descriptionletterSpacing_mobile": "",
      "descriptiontypographyBold": "",
      "descriptiontypographyItalic": "",
      "descriptiontypographyUnderline": "",
      "descriptionalign": "",
      "descriptiontypographyLetterCase": "",
      "titlefont": "",
      "titlefontVariant": "",
      "titlefontSize": "",
      "titlefontSize_mobile": "",
      "titlelineHeight": "",
      "titlelineHeight_mobile": "",
      "titleletterSpacing": "",
      "titleletterSpacing_mobile": "",
      "titletypographyBold": "",
      "titletypographyItalic": "",
      "titletypographyUnderline": "",
      "titlealign": "",
      "titletypographyLetterCase": "",
      "pricefont": "",
      "pricefontVariant": "",
      "pricefontSize": "",
      "pricefontSize_mobile": "",
      "pricelineHeight": "",
      "pricelineHeight_mobile": "",
      "priceletterSpacing": "",
      "priceletterSpacing_mobile": "",
      "pricetypographyBold": "",
      "pricetypographyItalic": "",
      "pricetypographyUnderline": "",
      "pricealign": "",
      "pricetypographyLetterCase": "",
      "priceColor": "",
      "buttonStyle": "flat",
      "buttonBgColor": "",
      "buttonShadow": "",
      "buttonLineHeight": "",
      "buttonfont": "",
      "buttonfontVariant": "",
      "buttonfontSize": "",
      "buttonfontSize_mobile": "",
      "buttonlineHeight": "",
      "buttonlineHeight_mobile": "",
      "buttonletterSpacing": "",
      "buttonletterSpacing_mobile": "",
      "buttontypographyBold": "",
      "buttontypographyItalic": "",
      "buttontypographyUnderline": "",
      "buttonalign": "",
      "buttontypographyLetterCase": "",
      "buttonSize":"4",
      "buttonPaddingTop": "16",
      "buttonPaddingLeft": "20",
      "buttonBorderRadius": "",
      "imageShadow": "",
      "imageBorderRadius": "",
      "imageBorderStyle": "",
      "imageBorderColor": "",
      "imageBorderTop": "1",
      "imageBorderBottom": "1",
      "imageBorderLeft": "1",
      "imageBorderRight": "1",
      "imageBorderSync": true,
      "imagePadding": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "upsells":{
      "columns": "1",
      "pagination": false,
      "limit": "-1",
      "showItemsCount": false,
      "showOrderBy": false,
      "selectProductIds": false,
      "productIds": [],
      "selectProductSkus": false,
      "productSkus": [],
      "selectCategories": false,
      "productCategories": [],
      "queryCategoriesOperator": "IN",
      "selectTags": false,
      "productTags": [],
      "queryTagsOperator": "IN",
      "selectGroup": false,
      "productGroups": "",
      "selectByVisibility": false,
      "productVisibility": "",
      "queryByAttribute": false,
      "queryAttribute": "",
      "queryAttributeTerms": [],
      "queryTermsOperator": "IN",
      "querySource": "upsells",
      "queryInclude": "",
      "queryIncludeBy": "",
      "queryIncludeTerm": "",
      "queryExclude": "",
      "queryExcludeBy": "",
      "queryExcludeTerm": "",
      "queryOrderBy": [],
      "queryOrder": "ASC",
      "align": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "marginTop_mobile": "",
      "marginBottom_mobile": "",
      "marginLeft_mobile": "",
      "marginRight_mobile": "",
      "marginSync_mobile": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "paddingTop_mobile": "",
      "paddingBottom_mobile": "",
      "paddingLeft_mobile": "",
      "paddingRight_mobile": "",
      "paddingSync_mobile": true,
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "descriptionfont": "",
      "descriptionfontVariant": "",
      "descriptionfontSize": "",
      "descriptionfontSize_mobile": "",
      "descriptionlineHeight": "",
      "descriptionlineHeight_mobile": "",
      "descriptionletterSpacing": "",
      "descriptionletterSpacing_mobile": "",
      "descriptiontypographyBold": "",
      "descriptiontypographyItalic": "",
      "descriptiontypographyUnderline": "",
      "descriptionalign": "",
      "descriptiontypographyLetterCase": "",
      "titlefont": "",
      "titlefontVariant": "",
      "titlefontSize": "",
      "titlefontSize_mobile": "",
      "titlelineHeight": "",
      "titlelineHeight_mobile": "",
      "titleletterSpacing": "",
      "titleletterSpacing_mobile": "",
      "titletypographyBold": "",
      "titletypographyItalic": "",
      "titletypographyUnderline": "",
      "titlealign": "",
      "titletypographyLetterCase": "",
      "pricefont": "",
      "pricefontVariant": "",
      "pricefontSize": "",
      "pricefontSize_mobile": "",
      "pricelineHeight": "",
      "pricelineHeight_mobile": "",
      "priceletterSpacing": "",
      "priceletterSpacing_mobile": "",
      "pricetypographyBold": "",
      "pricetypographyItalic": "",
      "pricetypographyUnderline": "",
      "pricealign": "",
      "pricetypographyLetterCase": "",
      "priceColor": "",
      "buttonStyle": "flat",
      "buttonBgColor": "",
      "buttonShadow": "",
      "buttonLineHeight": "",
      "buttonfont": "",
      "buttonfontVariant": "",
      "buttonfontSize": "",
      "buttonfontSize_mobile": "",
      "buttonlineHeight": "",
      "buttonlineHeight_mobile": "",
      "buttonletterSpacing": "",
      "buttonletterSpacing_mobile": "",
      "buttontypographyBold": "",
      "buttontypographyItalic": "",
      "buttontypographyUnderline": "",
      "buttonalign": "",
      "buttontypographyLetterCase": "",
      "buttonSize":"4",
      "buttonPaddingTop": "16",
      "buttonPaddingLeft": "20",
      "buttonBorderRadius": "",
      "imageShadow": "",
      "imageBorderRadius": "",
      "imageBorderStyle": "",
      "imageBorderColor": "",
      "imageBorderTop": "1",
      "imageBorderBottom": "1",
      "imageBorderLeft": "1",
      "imageBorderRight": "1",
      "imageBorderSync": true,
      "imagePadding": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "productrating":{
      "txt": "[sp_product_rating]",
      "label":"",
      "scale":"5",
      "rating":"5",
      "iconSize":"24",
      "spaceBetween":"",
      "align":"",
      "emptyStarColor":"",
      "color":"",
      "textColor":"",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "typographyLetterCase": "",
      "textfont": "",
      "textfontVariant": "",
      "textfontSize": "",
      "textfontSize_mobile": "",
      "textlineHeight": "",
      "textlineHeight_mobile": "",
      "textletterSpacing": "",
      "textletterSpacing_mobile": "",
      "texttypographyBold": "",
      "texttypographyItalic": "",
      "texttypographyUnderline": "",
      "texttypographyLetterCase": "",
      "textShadow":"",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "productstock":{
      "editortxt":"code",
      "txt": "[sp_product_stock]",
      "textColor": "",
      "bgColor": "",
      "beforeIcon": "",
      "afterIcon": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "borderRadius": "",
      "borderRadiusTL":"",
      "borderRadiusTR":"",
      "borderRadiusBL":"",
      "borderRadiusBR":"",
      "borderRadiusSync":true,
      "borderTop":"0",
      "borderBottom":"0",
      "borderLeft":"0",
      "borderRight":"0",
      "borderSync":true,
      "borderStyle":"solid",
      "border": "",
      "borderStyle": "",
      "borderSize": "",
      "borderColor": "",
      "shadow": "",
      "shadowColor":"",
      "shadowHorizontal":0,
      "shadowVertical":0,
      "shadowBlur":3,
      "shadowSpread":0,
      "shadowPosition":"outline",
      "textShadow": "",
      "textshadowColor":"",
      "textshadowHorizontal":0,
      "textshadowVertical":0,
      "textshadowBlur":3,
      "textshadowSpread":0,
      "textshadowPosition":"outline",
      "font": "",
      "fontVariant": "",
      "fontSize": "",
      "fontSize_mobile": "",
      "lineHeight": "",
      "lineHeight_mobile": "",
      "letterSpacing": "",
      "letterSpacing_mobile": "",
      "typographyBold": "",
      "typographyItalic": "",
      "typographyUnderline": "",
      "align": "left",
      "typographyLetterCase": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    },
    "archiveproducts":{
      "columns": "4",
      "pagination": false,
      "limit": "-1",
      "showItemsCount": false,
      "showOrderBy": false,
      "selectProductIds": false,
      "productIds": [],
      "selectProductSkus": false,
      "productSkus": [],
      "selectCategories": false,
      "productCategories": [],
      "queryCategoriesOperator": "IN",
      "selectTags": false,
      "productTags": [],
      "queryTagsOperator": "IN",
      "selectGroup": false,
      "productGroups": "",
      "selectByVisibility": false,
      "productVisibility": "",
      "queryByAttribute": false,
      "queryAttribute": "",
      "queryAttributeTerms": [],
      "queryTermsOperator": "IN",
      "querySource": "archive_products",
      "queryInclude": "",
      "queryIncludeBy": "",
      "queryIncludeTerm": "",
      "queryExclude": "",
      "queryExcludeBy": "",
      "queryExcludeTerm": "",
      "queryOrderBy": [],
      "queryOrder": "ASC",
      "align": "",
      "marginTop": "",
      "marginBottom": "",
      "marginLeft": "",
      "marginRight": "",
      "marginSync": false,
      "customClass":"",
      "paddingTop": "",
      "paddingBottom": "",
      "paddingLeft": "",
      "paddingRight": "",
      "paddingSync": true,
      "btnStyle": "flat",
      "btnBgColor": "",
      "btnBorderRadius": "",
      "descriptionfont": "",
      "descriptionfontVariant": "",
      "descriptionfontSize": "",
      "descriptionfontSize_mobile": "",
      "descriptionlineHeight": "",
      "descriptionlineHeight_mobile": "",
      "descriptionletterSpacing": "",
      "descriptionletterSpacing_mobile": "",
      "descriptiontypographyBold": "",
      "descriptiontypographyItalic": "",
      "descriptiontypographyUnderline": "",
      "descriptionalign": "",
      "descriptiontypographyLetterCase": "",
      "pricefont": "",
      "pricefontVariant": "",
      "pricefontSize": "",
      "pricefontSize_mobile": "",
      "pricelineHeight": "",
      "pricelineHeight_mobile": "",
      "priceletterSpacing": "",
      "priceletterSpacing_mobile": "",
      "pricetypographyBold": "",
      "pricetypographyItalic": "",
      "pricetypographyUnderline": "",
      "pricealign": "",
      "pricetypographyLetterCase": "",
      "priceColor": "",
      "saleColor":"",
      "buttonStyle": "flat",
      "buttonBgColor": "",
      "buttonShadow": "",
      "buttonLineHeight": "",
      "buttonfont": "",
      "buttonfontVariant": "",
      "buttonfontSize": "",
      "buttonfontSize_mobile": "",
      "buttonlineHeight": "",
      "buttonlineHeight_mobile": "",
      "buttonletterSpacing": "",
      "buttonletterSpacing_mobile": "",
      "buttontypographyBold": "",
      "buttontypographyItalic": "",
      "buttontypographyUnderline": "",
      "buttonalign": "",
      "buttontypographyLetterCase": "",
      "buttonSize":"4",
      "buttonPaddingTop": "16",
      "buttonPaddingLeft": "20",
      "buttonBorderRadius": "",
      "imageShadow": "",
      "imageBorderRadius": "3",
      "imageBorderStyle": "solid",
      "imageBorderColor": "#ccc",
      "imageBorderTop": "1",
      "imageBorderBottom": "1",
      "imageBorderLeft": "1",
      "imageBorderRight": "1",
      "imageBorderSync": true,
      "imagePadding": "",
      "hideOnDesktop": false,
      "hideOnMobile": false
    }
 }';
